"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const testTxHashes_js_1 = require("../__tests__/testTxHashes.js");
const Interpreter_1 = __importDefault(require("../core/Interpreter"));
const index_1 = require("../index");
const dotenv_1 = __importDefault(require("dotenv"));
const mongoose_1 = require("../utils/mongoose");
dotenv_1.default.config();
jest.mock('node-fetch', () => jest.fn());
jest.useRealTimers();
test('Interpreter', () => __awaiter(void 0, void 0, void 0, function* () {
    jest.setTimeout(200 * 1000);
    const db = new mongoose_1.MongooseDatabaseInterface(process.env.EVM_TRANSLATOR_CONNECTION_STRING || '');
    yield db.connect();
    const interpreter = new Interpreter_1.default(index_1.chains.ethereum);
    const txMap = yield db.getManyDecodedTxMap((0, testTxHashes_js_1.flattenTxHashes)());
    const filteredDecodedTxes = Object.entries(txMap)
        .filter(([txHash, decodedTx]) => {
        if (!decodedTx) {
            console.log('Issue with decoder for tx:', txHash);
            return false;
        }
        return true;
    })
        .map(([, decodedTx]) => decodedTx);
    for (const decodedTx of filteredDecodedTxes) {
        if (testTxHashes_js_1.multiSidedTxMap[decodedTx.txHash]) {
            // test multiple roles for a single tx
            for (const participant of testTxHashes_js_1.multiSidedTxMap[decodedTx.txHash]) {
                yield expect(interpreter.interpretSingleTx(decodedTx, participant)).resolves.toMatchSnapshot();
            }
        }
        else {
            yield expect(interpreter.interpretSingleTx(decodedTx)).resolves.toMatchSnapshot();
        }
    }
    yield db.closeConnection();
}), 200000);
//# sourceMappingURL=Interpreter.test.js.map