import { AlchemyProvider, Formatter, StaticJsonRpcProvider } from '@ethersproject/providers';
import { ABI_Item, ABI_ItemUnfiltered } from '../interfaces/abi';
import { CovalentTxData } from '../interfaces/covalent';
import { ContractData, ContractType, DecodedCallData, DecodedTx, Interaction } from '../interfaces/decoded';
import { RawTxData, TraceLog } from '../interfaces/rawData';
import { Chain } from '../interfaces/utils';
import Covalent from '../utils/clients/Covalent';
import Etherscan from '../utils/clients/Etherscan';
import { DatabaseInterface } from '../utils/DatabaseInterface';
export declare type DecoderConfig = {
    covalentData?: CovalentTxData;
    useNodeForENS: boolean;
    use4ByteDirectory: boolean;
    useTinTin: boolean;
};
export declare class Augmenter {
    provider: AlchemyProvider | StaticJsonRpcProvider;
    covalent: Covalent | null;
    etherscan: Etherscan;
    db: DatabaseInterface;
    formatter: Formatter;
    chain: Chain;
    rawTxDataArr: RawTxData[];
    decodedArr: DecodedTx[];
    fnSigCache: Record<string, string>;
    ensCache: Record<string, string>;
    constructor(provider: AlchemyProvider | StaticJsonRpcProvider, covalent: Covalent | null, etherscan: Etherscan, databaseInterface?: DatabaseInterface);
    decodeTxData(rawTxData: RawTxData, abiMap: Record<string, ABI_Item[]>, contractDataMap: Record<string, ContractData>): Promise<{
        decodedLogs: Interaction[];
        decodedCallData: DecodedCallData;
        decodedTraceData: DecodedCallData[];
    }>;
    augmentDecodedData(decodedLogs: Interaction[], decodedCallData: DecodedCallData, decodedTraceData: DecodedCallData[], ensMap: Record<string, string>, contractDataMap: Record<string, ContractData>, rawTxData: RawTxData): DecodedTx;
    static augmentTraceLogs(interactionsWithoutNativeTransfers: Interaction[], traceLogs: TraceLog[]): Interaction[];
    getENSNames(addresses: string[]): Promise<Record<string, string>>;
    static augmentENSNames(decoded: DecodedTx, ensMap: Record<string, string>): DecodedTx;
    downloadContractsFromTinTin(): Promise<ContractData[]>;
    getNameAndSymbol(address: string, contractType: ContractType): Promise<{
        tokenName: string | null;
        tokenSymbol: string | null;
        contractName: string | null;
    }>;
    getContractType(contractAddress: string, abiArr?: ABI_ItemUnfiltered[] | null): Promise<ContractType>;
    private getContractTypes;
    getContractsData(contractToAbiMap: Record<string, ABI_ItemUnfiltered[]>, contractToOfficialNameMap: Record<string, string | null>, proxyAddressMap: Record<string, string>): Promise<Record<string, ContractData>>;
    getProxyContractMap(contractAddresses: string[]): Promise<Record<string, string>>;
    getABIsAndNamesForContracts(contractAddresses: string[]): Promise<[Record<string, ABI_ItemUnfiltered[]>, Record<string, string | null>]>;
    static getAllAddresses(decodedLogs: Interaction[], decodedCallData: DecodedCallData, contractAddresses: string[]): string[];
}
