"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Augmenter = void 0;
const MulticallTxInterpreter_1 = require("./MulticallTxInterpreter");
const transformDecodedLogs_1 = require("./transformDecodedLogs");
const providers_1 = require("@ethersproject/providers");
const axios_1 = __importDefault(require("axios"));
const ethers_1 = require("ethers");
const traverse_1 = __importDefault(require("traverse"));
const rawData_1 = require("../interfaces/rawData");
const utils_1 = require("../interfaces/utils");
const utils_2 = require("../utils");
const abi_decoder_1 = __importDefault(require("../utils/abi-decoder"));
const ABIs_1 = __importDefault(require("../utils/ABIs"));
const ReverseRecords_json_1 = __importDefault(require("../utils/ABIs/ReverseRecords.json"));
const checkInterface_1 = __importDefault(require("../utils/checkInterface"));
const constants_1 = require("../utils/constants");
const DatabaseInterface_1 = require("../utils/DatabaseInterface");
const getTypeFromABI_1 = __importDefault(require("../utils/getTypeFromABI"));
const isGnosisSafeMaybe_1 = __importDefault(require("../utils/isGnosisSafeMaybe"));
const logging_1 = require("../utils/logging");
class Augmenter {
    constructor(provider, covalent, etherscan, databaseInterface = new DatabaseInterface_1.NullDatabaseInterface()) {
        this.formatter = new providers_1.Formatter();
        this.fnSigCache = {};
        this.ensCache = {};
        this.provider = provider;
        this.covalent = covalent;
        this.etherscan = etherscan;
        this.db = databaseInterface;
        this.chain = (0, utils_2.getChainById)(this.provider.network.chainId);
    }
    decodeTxData(rawTxData, abiMap, contractDataMap) {
        return __awaiter(this, void 0, void 0, function* () {
            const abiDecoder = new abi_decoder_1.default(this.db);
            abiDecoder.addABI(abiMap);
            const { logs } = rawTxData.txReceipt;
            const rawDecodedLogs = yield abiDecoder.decodeLogs(logs, contractDataMap);
            const rawDecodedCallData = (yield abiDecoder.decodeMethod(rawTxData.txResponse.data)) || {
                name: null,
                params: [],
            };
            const rawDecodedTraceData = yield (0, MulticallTxInterpreter_1.decodeRawTxTrace)(abiDecoder, (rawTxData === null || rawTxData === void 0 ? void 0 : rawTxData.txTrace) || []);
            const decodedLogs = (0, transformDecodedLogs_1.transformDecodedLogs)(rawDecodedLogs, contractDataMap);
            const decodedCallData = (0, transformDecodedLogs_1.transformDecodedData)(rawDecodedCallData);
            const decodedTraceData = (0, transformDecodedLogs_1.transformTraceData)(rawDecodedTraceData);
            return { decodedLogs, decodedCallData, decodedTraceData };
        });
    }
    augmentDecodedData(decodedLogs, decodedCallData, decodedTraceData, ensMap, contractDataMap, rawTxData) {
        var _a, _b;
        const { txReceipt, txResponse } = rawTxData;
        const value = rawTxData.txResponse.value.toString();
        let txType;
        if (!txReceipt.to) {
            txType = "contract deploy" /* TxType.CONTRACT_DEPLOY */;
        }
        else if (txResponse.data == '0x') {
            txType = "native token transfer" /* TxType.TRANSFER */;
        }
        else {
            // TODO txReceipt.contractAddress is the address of the contract created, add it
            txType = "contract interaction" /* TxType.CONTRACT_INTERACTION */;
        }
        const fromENS = ensMap[txReceipt.from] || null;
        const toENS = ensMap[txReceipt.to || ''] || null;
        const interactions = 'txTrace' in rawTxData ? Augmenter.augmentTraceLogs(decodedLogs, rawTxData.txTrace) : decodedLogs;
        const interpreterMap = txReceipt.to ? contractDataMap[txReceipt.to] : null;
        const transformedData = {
            txHash: txResponse.hash,
            txType: txType,
            fromAddress: txReceipt.from,
            toAddress: txReceipt.to,
            officialContractName: (interpreterMap === null || interpreterMap === void 0 ? void 0 : interpreterMap.contractOfficialName) || null,
            contractName: (interpreterMap === null || interpreterMap === void 0 ? void 0 : interpreterMap.contractName) || null,
            contractType: (interpreterMap === null || interpreterMap === void 0 ? void 0 : interpreterMap.type) || "OTHER" /* ContractType.OTHER */,
            methodCall: Object.assign({ name: decodedCallData.name, arguments: decodedCallData.params }, (!decodedCallData.decoded && { decoded: decodedCallData.decoded })),
            traceCalls: decodedTraceData,
            nativeValueSent: value,
            chainSymbol: this.chain.symbol,
            interactions,
            effectiveGasPrice: ((_a = txReceipt.effectiveGasPrice) === null || _a === void 0 ? void 0 : _a.toString()) || ((_b = txResponse.gasPrice) === null || _b === void 0 ? void 0 : _b.toString()) || null,
            gasUsed: txReceipt.gasUsed.toString(),
            timestamp: txReceipt.timestamp,
            txIndex: txReceipt.transactionIndex,
            reverted: txReceipt.status == 0,
            fromENS,
            toENS,
        };
        const transformedAugmentedData = Augmenter.augmentENSNames(transformedData, ensMap);
        return transformedAugmentedData;
    }
    static augmentTraceLogs(interactionsWithoutNativeTransfers, traceLogs) {
        const interactions = [...interactionsWithoutNativeTransfers];
        function traceLogToEvent(nativeTransfer) {
            const { action, type } = nativeTransfer;
            const generalNativeEvent = {
                nativeTransfer: true,
                logIndex: null,
            };
            switch (type) {
                case rawData_1.TraceType.enum.call:
                    return Object.assign({ eventName: 'NativeTransfer', params: {
                            from: action.from,
                            to: action.to,
                            value: action.value.toString(),
                        } }, generalNativeEvent);
                case rawData_1.TraceType.enum.create:
                    return Object.assign({ eventName: 'NativeCreate', params: {
                            from: action.from,
                            value: action.value.toString(),
                        } }, generalNativeEvent);
                case rawData_1.TraceType.enum.suicide:
                    return Object.assign({ eventName: 'NativeSuicide', params: {
                            from: action.address,
                            refundAddress: action.refundAddress,
                            balance: action.balance.toString(),
                        } }, generalNativeEvent);
                case rawData_1.TraceType.enum.reward:
                    return Object.assign({ eventName: 'NativeReward', params: {
                            author: action.author,
                            rewardType: action.rewardType,
                            value: action.value.toString(),
                        } }, generalNativeEvent);
                default:
                    return Object.assign({ eventName: 'NativeUnknown', params: {} }, generalNativeEvent);
            }
        }
        function filterToNativeTransfers(traceLogs) {
            const nativeTransfers = [];
            for (let i = 0; i < traceLogs.length; i++) {
                const traceLog = traceLogs[i];
                if (traceLog.type === rawData_1.TraceType.enum.call &&
                    traceLog.action.callType == 'call' &&
                    !traceLog.action.value.isZero() &&
                    !traceLog.error) {
                    nativeTransfers.push(traceLog);
                }
            }
            return nativeTransfers;
        }
        const nativeTransfers = filterToNativeTransfers(traceLogs);
        // add native transfers to interactions array
        for (const nt of nativeTransfers) {
            const interaction = interactions.find((i) => i.contractAddress == nt.action.from || i.contractAddress == nt.action.to);
            // usually it comes from one of the contracts that emitted other events
            if (interaction) {
                interaction.events.push(traceLogToEvent(nt));
                // but sometimes... it doesn't, so we need to add that contract
            }
            else {
                interactions.push({
                    contractAddress: nt.action.from,
                    contractName: null,
                    contractSymbol: null,
                    contractType: "OTHER" /* ContractType.OTHER */,
                    events: [traceLogToEvent(nt)],
                });
            }
        }
        return interactions;
    }
    getENSNames(addresses) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.chain.symbol !== 'ETH')
                return {};
            const reverseRecords = new ethers_1.Contract(constants_1.REVERSE_RECORDS_CONTRACT_ADDRESS, ReverseRecords_json_1.default, this.provider);
            let allDirtyNames = [];
            try {
                allDirtyNames = (yield reverseRecords.getNames(addresses));
            }
            catch (e) {
                (0, logging_1.logWarning)({
                    function_name: 'getENSNames',
                }, `Error getting ENS names. ${addresses.length} in the array. Dunno which one triggered the error.`);
                allDirtyNames = new Array(addresses.length).fill('');
            }
            // remove illegal chars TODO allow more chars
            const names = allDirtyNames.map((name) => {
                return name.replace(/([^\w\s+*:;,.()\-/\\]+)/gi, '¿');
            });
            let addressToNameMap = {};
            addresses.forEach((address, index) => {
                addressToNameMap[address] = names[index];
            });
            // TODO handle arrays of addresses
            // "events":[
            //     :{
            //     "event":"SafeSetup"
            //     "logIndex":112
            //     "initiator":"0xa6b71e26c5e0845f74c812102ca7114b6a896ab2"
            //     "owners":[
            //     :"0x17a059b6b0c8af433032d554b0392995155452e6"
            //     :"0x13e2ed5724e9d6df54ed1ea5b4fa81310458c1d9"
            //     :"0x825728f78912b98adfb06380f1fcdcda76fd0f87"
            //     ]
            //     "threshold":"2"
            //     "initializer":"0x0000000000000000000000000000000000000000"
            //     "fallbackHandler":"0xf48f2b2d2a534e402487b3ee7c18c33aec0fe5e4"
            //     }
            // ]
            // filter out addresses:names with no names (most of them lol)
            addressToNameMap = Object.fromEntries(Object.entries(addressToNameMap).filter(([, v]) => v != ''));
            return addressToNameMap;
        });
    }
    static augmentENSNames(decoded, ensMap) {
        const decodedWithENS = (0, traverse_1.default)(decoded).map((thing) => {
            if (!!thing && typeof thing === 'object' && !Array.isArray(thing)) {
                for (const [key, val] of Object.entries(thing)) {
                    if (typeof val === 'string') {
                        if (ensMap[val]) {
                            if (key == 'toAddress') {
                                thing.toENS = ensMap[val];
                            }
                            else if (key == 'fromAddress') {
                                thing.fromENS = ensMap[val];
                            }
                            else {
                                thing[key + 'ENS'] = ensMap[val];
                            }
                        }
                    }
                }
            }
        });
        return decodedWithENS;
    }
    downloadContractsFromTinTin() {
        return __awaiter(this, void 0, void 0, function* () {
            // TODO programmatically get the latest hash of this repo and use that instead of this hardcoded one
            const mainnetTinTinUrl = 'https://raw.githubusercontent.com/tintinweb/smart-contract-sanctuary-ethereum/eb6b57e33f0a157c3688024a1eead4ea85753bd1/contracts/mainnet/contracts.json';
            const contractMapping = (yield axios_1.default.get(mainnetTinTinUrl).then((res) => JSON.parse(`[${res.data.replaceAll('}', '},').slice(0, -2)}]`).map((mapping) => ({
                address: mapping.address,
                contractOfficialName: mapping.name,
                txCount: mapping.txCount,
                type: "OTHER" /* ContractType.OTHER */,
                tokenName: null,
                tokenSymbol: null,
                contractName: null,
                abi: [],
                proxyAddress: null,
            }))));
            yield this.db.addOrUpdateManyContractData(contractMapping);
            return contractMapping;
        });
    }
    getNameAndSymbol(address, contractType) {
        return __awaiter(this, void 0, void 0, function* () {
            const abi = ABIs_1.default[contractType];
            const contract = new ethers_1.Contract(address, abi, this.provider);
            const namePromise = contract.name();
            const symbolPromise = contract.symbol();
            const results = yield Promise.allSettled([namePromise, symbolPromise]);
            const contractName = results[0].status === 'fulfilled' ? results[0].value : null;
            const tokenSymbol = results[1].status === 'fulfilled' ? results[1].value : null;
            let tokenName = null;
            if (contractType === "ERC20" /* ContractType.ERC20 */ ||
                contractType === "ERC721" /* ContractType.ERC721 */ ||
                contractType === "ERC1155" /* ContractType.ERC1155 */) {
                tokenName = contractName;
            }
            return { tokenName, tokenSymbol, contractName };
        });
    }
    getContractType(contractAddress, abiArr = null) {
        return __awaiter(this, void 0, void 0, function* () {
            if (contractAddress == this.chain.wethAddress) {
                return "WETH" /* ContractType.WETH */;
            }
            if (contractAddress == this.chain.usdcAddress) {
                return "ERC20" /* ContractType.ERC20 */;
            }
            let contractType = yield (0, checkInterface_1.default)(contractAddress, this.provider);
            if (contractType === "OTHER" /* ContractType.OTHER */) {
                contractType = yield (0, getTypeFromABI_1.default)(contractAddress, this.etherscan, abiArr);
            }
            if (contractType === "OTHER" /* ContractType.OTHER */) {
                contractType = yield (0, isGnosisSafeMaybe_1.default)(contractAddress, this.provider);
            }
            // if (contractType === ContractType.OTHER) {
            //     try {
            //         const code = await this.provider.getCode(contractAddress)
            //         if (code == '0x') {
            //             contractType = ContractType.EOA
            //         }
            //     } catch (e) {
            //         logError({ functionName: 'provider.getCode', address: contractAddress }, e)
            //     }
            // }
            return contractType;
        });
    }
    getContractTypes() {
        return __awaiter(this, void 0, void 0, function* () {
            const contractTypes = yield Promise.all(this.rawTxDataArr.map((rawTxData, index) => __awaiter(this, void 0, void 0, function* () {
                let contractType = "OTHER" /* ContractType.OTHER */;
                if (this.decodedArr[index].txType == "contract interaction" /* TxType.CONTRACT_INTERACTION */ && rawTxData.txResponse.to) {
                    contractType = yield this.getContractType(rawTxData.txReceipt.to || constants_1.blackholeAddress); // WARNING hack for now
                }
                //     else if (this.decodedArr[index].txType == TX_TYPE.CONTRACT_DEPLOY) {
                //         //TODO
                // }
                return contractType;
            })));
            contractTypes.forEach((contractType, index) => {
                this.decodedArr[index].contractType = contractType;
            });
        });
    }
    getContractsData(contractToAbiMap, contractToOfficialNameMap, proxyAddressMap) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const contractDataMap = {};
                const filteredABIs = (0, utils_2.filterABIMap)(contractToAbiMap);
                const addresses = (0, utils_2.getKeys)(contractToAbiMap).map((address) => utils_1.AddressZ.parse(address));
                const contractDataMapFromDB = yield this.db.getManyContractDataMap(addresses);
                yield Promise.all(addresses.map((address) => __awaiter(this, void 0, void 0, function* () {
                    var _a, _b, _c, _d;
                    const proxyAddress = proxyAddressMap[address] || null;
                    const abi = contractToAbiMap[address];
                    // if the contract has a proxy, add the proxy's ABI too
                    if (proxyAddress)
                        abi.concat(contractToAbiMap[proxyAddress]);
                    let contractType = (_a = contractDataMapFromDB[address]) === null || _a === void 0 ? void 0 : _a.type;
                    if (!contractType || contractType === "OTHER" /* ContractType.OTHER */) {
                        contractType = yield this.getContractType(address, filteredABIs[address]);
                    }
                    let tokenName = null;
                    let tokenSymbol = null;
                    let contractName = null;
                    if (contractDataMapFromDB[address]) {
                        tokenName = ((_b = contractDataMapFromDB[address]) === null || _b === void 0 ? void 0 : _b.tokenName) || null;
                        tokenSymbol = ((_c = contractDataMapFromDB[address]) === null || _c === void 0 ? void 0 : _c.tokenSymbol) || null;
                        contractName = ((_d = contractDataMapFromDB[address]) === null || _d === void 0 ? void 0 : _d.contractName) || null;
                    }
                    // warning, we might assign contactName from somewhere else in the future, so it might not be null here even when we thought it would be, which means we might still need to get token symbol/name but we end up skipping it
                    // commented this out to make sure we get the token name/symbol from the contract. we'll end up always doing this call no matter what now but we can optimize later (WARNING)
                    if (!contractName || !tokenName || !tokenSymbol) {
                        ;
                        ({ tokenName, tokenSymbol, contractName } = yield this.getNameAndSymbol(address, contractType));
                    }
                    // const contractName = await this.getContractName(address)
                    const contractData = {
                        address,
                        type: contractType,
                        tokenName,
                        tokenSymbol,
                        abi,
                        contractName,
                        contractOfficialName: contractToOfficialNameMap[address],
                        proxyAddress,
                        txCount: null,
                    };
                    // console.log('contractData', contractData)
                    contractDataMap[address] = contractData;
                })));
                yield this.db.addOrUpdateManyContractData((0, utils_2.getValues)(contractDataMap).flat());
                return contractDataMap;
            }
            catch (e) {
                console.log('getContractsData', e);
                throw e;
            }
        });
    }
    getProxyContractMap(contractAddresses) {
        return __awaiter(this, void 0, void 0, function* () {
            const proxyMap = {};
            const proxyAddresses = yield (0, utils_2.getProxyAddresses)(this.provider, contractAddresses);
            for (const [index, proxyAddress] of proxyAddresses.entries()) {
                if (proxyAddress) {
                    proxyMap[contractAddresses[index]] = proxyAddress;
                }
            }
            return proxyMap;
        });
    }
    // TODO get the names
    getABIsAndNamesForContracts(contractAddresses) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const addresses = contractAddresses.map((a) => utils_1.AddressZ.parse(a));
                const logData = {
                    function_name: 'db.getManyContractDataMap',
                };
                const contractDataMapWithNulls = yield this.db.getManyContractDataMap(addresses);
                const addressesWithMissingABIs = (0, utils_2.getKeys)(contractDataMapWithNulls).filter((address) => { var _a; return !((_a = contractDataMapWithNulls[address]) === null || _a === void 0 ? void 0 : _a.abi); });
                addressesWithMissingABIs.forEach((address) => {
                    (0, logging_1.logDebug)({ address }, 'missing ABI. retrieving from etherscan');
                });
                const contractDataMap = Object.fromEntries(Object.entries(contractDataMapWithNulls).filter(([, v]) => v != null));
                // get abis from etherscan only for contracts we dont have an abi for
                logData.function_name = 'getABIs';
                const abiMapFromEtherscan = yield this.etherscan.getABIs(addressesWithMissingABIs);
                // an array of all abis
                const abiArray = (0, utils_2.getValues)(abiMapFromEtherscan).flat();
                // insert all abis into the abi table
                const filtered = (0, utils_2.filterABIArray)(abiArray);
                logData.function_name = 'db.addOrUpdateManyABI';
                yield this.db.addOrUpdateManyABI((0, utils_2.abiArrToAbiRows)(filtered));
                const AbiMapFromDB = (0, utils_2.getEntries)(contractDataMap).reduce((acc, [address, contractData]) => {
                    acc[address] = contractData.abi || null;
                    return acc;
                }, {});
                const abiMap = Object.assign(Object.assign({}, AbiMapFromDB), abiMapFromEtherscan);
                const nameMapFromDB = (0, utils_2.getEntries)(contractDataMap).reduce((acc, [address, contractData]) => {
                    acc[address] = contractData.contractOfficialName || null;
                    return acc;
                }, {});
                // TODO get names from 3rd party APIs
                const nameMapFromEtherscan = {};
                const nameMap = Object.assign(Object.assign({}, nameMapFromDB), nameMapFromEtherscan);
                return [abiMap, nameMap];
            }
            catch (e) {
                console.log('error getting ABIs', e);
                throw e;
            }
        });
    }
    static getAllAddresses(decodedLogs, decodedCallData, contractAddresses) {
        const addresses = [];
        (0, traverse_1.default)(decodedLogs).forEach(function (value) {
            if (this.isLeaf && (0, utils_2.isAddress)(value)) {
                addresses.push(utils_1.AddressZ.parse(value));
            }
        });
        (0, traverse_1.default)(decodedCallData).forEach(function (value) {
            if (this.isLeaf && (0, utils_2.isAddress)(value)) {
                addresses.push(utils_1.AddressZ.parse(value));
            }
        });
        return [...new Set([...addresses, ...contractAddresses])];
    }
}
exports.Augmenter = Augmenter;
//# sourceMappingURL=Augmenter.js.map