import { AlchemyProvider, Formatter, StaticJsonRpcProvider } from '@ethersproject/providers';
import { CovalentTxData } from '../interfaces/covalent';
import { RawTxData, TraceLog, TxReceipt, TxResponse } from '../interfaces/rawData';
import { EVMTransaction } from '../interfaces/s3';
import Covalent from '../utils/clients/Covalent';
export default class RawDataFetcher {
    provider: AlchemyProvider | StaticJsonRpcProvider;
    covalent: Covalent | null;
    formatter: Formatter;
    constructor(provider: AlchemyProvider | StaticJsonRpcProvider, covalent?: Covalent | null);
    static validateTxResponse(unvalidatedTxResponse: any): TxResponse;
    static validateTxReceipt(unvalidatedTxReceipt: any): TxReceipt;
    static validateTraceLogs(unvalidatedTraceLogs: any[]): TraceLog[];
    getTxHashesByBlockNumber(blockNumber: string): Promise<string[]>;
    getTxResponse(txHash: string): Promise<TxResponse>;
    getTxReceipt(txHash: string): Promise<TxReceipt>;
    getTxTrace(txHash: string): Promise<TraceLog[]>;
    getTxData(txHash: string): Promise<RawTxData>;
    getTxDataFromS3Tx(tx: EVMTransaction, timestamp: number): RawTxData;
    getTxDataWithoutTrace(txHash: string): Promise<RawTxData>;
    getTxDataWithCovalentByAddress(address: string, includedInitiatedTxs: boolean, includedNotInitiatedTxs: boolean, limit: number): Promise<{
        rawTxDataArr: RawTxData[];
        covalentTxDataArr: CovalentTxData[];
    }>;
    static getContractAddressesFromRawTxData(rawTxData: RawTxData): string[];
}
