"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../../utils");
function sentBaseToken(interpretation) {
    const currency = (0, utils_1.getStablecoinOrNativeWrappedAddressesBySymbol)(interpretation.chainSymbol);
    return !!interpretation.assetsSent.find((token) => currency.includes(token.address));
}
function receivedBaseToken(interpretation) {
    const currency = (0, utils_1.getStablecoinOrNativeWrappedAddressesBySymbol)(interpretation.chainSymbol);
    return !!interpretation.assetsReceived.find((token) => currency.includes(token.address));
}
function sentOtherToken(interpretation) {
    return interpretation.assetsSent.length > 0 && !sentBaseToken(interpretation);
}
function receivedOtherToken(interpretation) {
    return interpretation.assetsReceived.length > 0 && !receivedBaseToken(interpretation);
}
function isAirdrop(interpretation, userAddress, fromAddress) {
    if (interpretation.assetsReceived.length > 0 && userAddress !== fromAddress) {
        return true;
    }
    else {
        return false;
    }
}
function isClaimed(interpretation, userAddress, fromAddress) {
    return (isReceived(interpretation) &&
        userAddress === fromAddress &&
        !sentBaseToken(interpretation) &&
        !sentOtherToken(interpretation));
}
function isReceived(interpretation) {
    return ((receivedBaseToken(interpretation) || receivedOtherToken(interpretation)) &&
        !sentBaseToken(interpretation) &&
        !sentOtherToken(interpretation));
}
function isSent(interpretation) {
    return ((sentBaseToken(interpretation) || sentOtherToken(interpretation)) &&
        !receivedBaseToken(interpretation) &&
        !receivedOtherToken(interpretation));
}
function isBought(interpretation) {
    // TODO: sent usdc received eth/weth
    return sentBaseToken(interpretation) && receivedOtherToken(interpretation);
}
function isSold(interpretation) {
    // TODO sent ETH/weth received usdc/usdt/dai
    return sentOtherToken(interpretation) && receivedBaseToken(interpretation);
}
function isTraded(interpretation) {
    return sentOtherToken(interpretation) && receivedOtherToken(interpretation);
}
function isSwapped(interpretation) {
    // not true for eth/weth <--> usdc/usdt/dai, only true between themselves
    return sentBaseToken(interpretation) && receivedBaseToken(interpretation);
}
function getAction(interpretation, userAddress, fromAddress) {
    // Order matters here, some are sub/super sets of others
    // const isSentBaseToken = sentBaseToken(interpretation)
    // const isSentOtherToken = sentOtherToken(interpretation)
    // const isReceivedBaseToken = receivedBaseToken(interpretation)
    // const isReceivedOtherToken = receivedOtherToken(interpretation)
    // console.log('isSentBaseToken', isSentBaseToken)
    // console.log('isSentOtherToken', isSentOtherToken)
    // console.log('isReceivedBaseToken', isReceivedBaseToken)
    // console.log('isReceivedOtherToken', isReceivedOtherToken)
    if (isAirdrop(interpretation, userAddress, fromAddress)) {
        return "got airdropped" /* Action.gotAirdropped */;
    }
    else if (isClaimed(interpretation, userAddress, fromAddress)) {
        return "claimed" /* Action.claimed */;
    }
    else if (isReceived(interpretation)) {
        return "received" /* Action.received */;
    }
    else if (isSent(interpretation)) {
        return "sent" /* Action.sent */;
    }
    else if (isBought(interpretation)) {
        return "bought" /* Action.bought */;
    }
    else if (isSold(interpretation)) {
        return "sold" /* Action.sold */;
    }
    else if (isTraded(interpretation)) {
        return "traded" /* Action.traded */;
    }
    else if (isSwapped(interpretation)) {
        return "swapped" /* Action.swapped */;
    }
    return "______TODO______" /* Action.______TODO______ */;
}
function lastFallback(decodedData, interpretation) {
    var _a, _b, _c, _d, _e, _f;
    const { fromAddress, toAddress } = decodedData;
    const { chainSymbol, userAddress, assetsReceived: tokensReceived, assetsSent: tokensSent } = interpretation;
    interpretation.actions.push(getAction(interpretation, userAddress, fromAddress));
    const valueSent = ((_a = tokensSent[0]) === null || _a === void 0 ? void 0 : _a.amount) || `#${(_b = tokensSent[0]) === null || _b === void 0 ? void 0 : _b.tokenId}`;
    const symbolSent = ((_c = tokensSent[0]) === null || _c === void 0 ? void 0 : _c.symbol) || chainSymbol;
    const valueReceived = ((_d = tokensReceived[0]) === null || _d === void 0 ? void 0 : _d.amount) || `#${(_e = tokensReceived[0]) === null || _e === void 0 ? void 0 : _e.tokenId}`;
    const symbolReceived = ((_f = tokensReceived[0]) === null || _f === void 0 ? void 0 : _f.symbol) || chainSymbol;
    const action = interpretation.actions[0];
    if (interpretation.actions.length && action === "got airdropped" /* Action.gotAirdropped */) {
        interpretation.counterpartyName = fromAddress;
        interpretation.exampleDescription = `${interpretation.userName} ${interpretation.actions} ${interpretation.assetsReceived[0].symbol} from ${interpretation.counterpartyName}`;
    }
    else if (interpretation.actions.length &&
        (action === "received" /* Action.received */ || action === "bought" /* Action.bought */ || action === "claimed" /* Action.claimed */)) {
        interpretation.counterpartyName = toAddress;
        interpretation.exampleDescription = `${interpretation.userName} ${interpretation.actions} ${valueReceived} ${symbolReceived} from ${interpretation.counterpartyName}`;
    }
    else if (interpretation.actions.length && (action === "sold" /* Action.sold */ || action === "sent" /* Action.sent */)) {
        interpretation.counterpartyName = toAddress;
        interpretation.exampleDescription = `${interpretation.userName} ${interpretation.actions} ${valueSent} ${symbolSent} to ${interpretation.counterpartyName}`;
    }
    else if (interpretation.actions.length && action === "traded" /* Action.traded */) {
        interpretation.counterpartyName = toAddress;
        interpretation.exampleDescription = `${interpretation.userName} ${interpretation.actions} ${valueSent} ${symbolSent} for ${valueReceived} ${symbolReceived} with ${interpretation.counterpartyName}`;
    }
}
exports.default = lastFallback;
//# sourceMappingURL=lastFallback.js.map