"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function isSafeReceivedEvent(event, userAddress) {
    return event.eventName === 'SafeReceived' && event.params.sender === userAddress;
}
function interpretGenericTransfer(decodedData, interpretation, fromName, toName) {
    var _a, _b;
    const { fromAddress, toAddress, interactions } = decodedData;
    const { userAddress, chainSymbol, userName } = interpretation;
    const sending = fromAddress === userAddress;
    const action = sending ? "sent" /* Action.sent */ : "received" /* Action.received */;
    const direction = sending ? 'to' : 'from';
    const tokenContractInteraction = interactions.find((interaction) => interaction.contractAddress === toAddress);
    const tokenEvents = (tokenContractInteraction === null || tokenContractInteraction === void 0 ? void 0 : tokenContractInteraction.events) || [];
    const isSafeReceived = tokenEvents.find((e) => isSafeReceivedEvent(e, userAddress));
    let counterpartyName = null;
    let amountSent = (_a = interpretation.assetsSent.find((asset) => asset.type === "native" /* AssetType.native */)) === null || _a === void 0 ? void 0 : _a.amount;
    if (isSafeReceived && sending) {
        // TODO confirm safeReceived is decoded
        counterpartyName = `Gnosis Safe ${decodedData.toENS || toName}`;
    }
    else if (sending) {
        counterpartyName = decodedData.toENS || toName;
    }
    else {
        counterpartyName = decodedData.fromENS || fromName;
        amountSent = (_b = interpretation.assetsReceived.find((asset) => asset.type === "native" /* AssetType.native */)) === null || _b === void 0 ? void 0 : _b.amount;
    }
    const exampleDescription = `${userName} ${action} ${amountSent} ${chainSymbol} ${direction} ${counterpartyName}`;
    interpretation.actions = [action];
    interpretation.exampleDescription = exampleDescription;
    interpretation.extra = {};
    if (counterpartyName) {
        interpretation.counterpartyName = counterpartyName;
    }
}
exports.default = interpretGenericTransfer;
//# sourceMappingURL=transfer.js.map