"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ABI_RowZ = exports.ABI_RowErrorZ = exports.ABI_RowFallbackZ = exports.ABI_RowReceiveZ = exports.ABI_RowEventZ = exports.ABI_RowFunctionZ = exports.ABI_RowConstructorZ = exports.ABI_ItemZ = exports.ABI_ItemUnfilteredZ = exports.ABI_ErrorZ = exports.ABI_FallbackZ = exports.ABI_ReceiveZ = exports.ABI_EventZ = exports.ABI_FunctionZ = exports.ABI_ConstructorZ = exports.readStates = exports.writeStates = exports.StateMutability = exports.ABI_Type = void 0;
const zod_1 = require("zod");
const utils_1 = require("../interfaces/utils");
const ABI_FunctionOutputZ = zod_1.z.object({
    name: utils_1.string.optional(),
    type: utils_1.string,
    components: zod_1.z.array(zod_1.z.any()).optional(),
});
const ABI_FunctionInputZ = zod_1.z.object({
    name: utils_1.string.optional(),
    type: utils_1.string,
    components: zod_1.z.array(zod_1.z.any()).optional(),
});
const ABI_EventInputZ = ABI_FunctionInputZ.extend({ indexed: utils_1.boolean });
exports.ABI_Type = zod_1.z.enum(['function', 'event', 'constructor', 'fallback', 'receive', 'error']);
exports.StateMutability = zod_1.z.enum(['pure', 'view', 'nonpayable', 'payable']);
exports.writeStates = [exports.StateMutability.enum.payable, exports.StateMutability.enum.nonpayable];
exports.readStates = [exports.StateMutability.enum.view, exports.StateMutability.enum.pure];
exports.ABI_ConstructorZ = zod_1.z.object({
    type: zod_1.z.literal(exports.ABI_Type.enum.constructor),
    inputs: zod_1.z.array(ABI_FunctionInputZ),
    stateMutability: exports.StateMutability.optional(),
});
exports.ABI_FunctionZ = zod_1.z.object({
    type: zod_1.z.literal(exports.ABI_Type.enum.function),
    name: utils_1.string,
    inputs: zod_1.z.array(ABI_FunctionInputZ),
    outputs: zod_1.z.array(ABI_FunctionOutputZ),
    stateMutability: exports.StateMutability.optional(),
    constant: utils_1.boolean.optional(),
    payable: utils_1.boolean.optional(),
});
exports.ABI_EventZ = zod_1.z.object({
    type: zod_1.z.literal(exports.ABI_Type.enum.event),
    name: utils_1.string,
    inputs: zod_1.z.array(ABI_EventInputZ),
    anonymous: utils_1.boolean,
});
exports.ABI_ReceiveZ = zod_1.z.object({
    type: zod_1.z.literal(exports.ABI_Type.enum.receive),
    stateMutability: exports.StateMutability.optional(),
    constant: utils_1.boolean.optional(),
    payable: utils_1.boolean.optional(),
});
exports.ABI_FallbackZ = zod_1.z.object({
    type: zod_1.z.literal(exports.ABI_Type.enum.fallback),
    stateMutability: exports.StateMutability.optional(),
    constant: utils_1.boolean.optional(),
    payable: utils_1.boolean.optional(),
});
exports.ABI_ErrorZ = zod_1.z.object({
    type: zod_1.z.literal(exports.ABI_Type.enum.error),
    name: utils_1.string,
    inputs: zod_1.z.array(ABI_FunctionInputZ),
});
exports.ABI_ItemUnfilteredZ = zod_1.z.discriminatedUnion('type', [
    exports.ABI_ConstructorZ,
    exports.ABI_FunctionZ,
    exports.ABI_EventZ,
    exports.ABI_ErrorZ,
    exports.ABI_FallbackZ,
    exports.ABI_ReceiveZ,
]);
exports.ABI_ItemZ = zod_1.z.discriminatedUnion('type', [exports.ABI_FunctionZ, exports.ABI_EventZ]);
exports.ABI_RowConstructorZ = zod_1.z.object({
    name: utils_1.string,
    type: zod_1.z.literal(exports.ABI_Type.enum.constructor),
    hashableSignature: utils_1.string,
    hashedSignature: utils_1.string,
    fullSignature: utils_1.string,
    abiJSON: exports.ABI_ConstructorZ,
    default: utils_1.boolean.optional(),
});
exports.ABI_RowFunctionZ = zod_1.z.object({
    name: utils_1.string,
    type: zod_1.z.literal(exports.ABI_Type.enum.function),
    hashableSignature: utils_1.string,
    hashedSignature: utils_1.string,
    fullSignature: utils_1.string,
    abiJSON: exports.ABI_FunctionZ,
    default: utils_1.boolean.optional(),
});
exports.ABI_RowEventZ = zod_1.z.object({
    name: utils_1.string,
    type: zod_1.z.literal(exports.ABI_Type.enum.event),
    hashableSignature: utils_1.string,
    hashedSignature: utils_1.string,
    fullSignature: utils_1.string,
    abiJSON: exports.ABI_EventZ,
    default: utils_1.boolean.optional(),
});
exports.ABI_RowReceiveZ = zod_1.z.object({
    name: utils_1.string,
    type: zod_1.z.literal(exports.ABI_Type.enum.receive),
    hashableSignature: utils_1.string,
    hashedSignature: utils_1.string,
    fullSignature: utils_1.string,
    abiJSON: exports.ABI_ReceiveZ,
    default: utils_1.boolean.optional(),
});
exports.ABI_RowFallbackZ = zod_1.z.object({
    name: utils_1.string,
    type: zod_1.z.literal(exports.ABI_Type.enum.fallback),
    hashableSignature: utils_1.string,
    hashedSignature: utils_1.string,
    fullSignature: utils_1.string,
    abiJSON: exports.ABI_FallbackZ,
    default: utils_1.boolean.optional(),
});
exports.ABI_RowErrorZ = zod_1.z.object({
    name: utils_1.string,
    type: zod_1.z.literal(exports.ABI_Type.enum.error),
    hashableSignature: utils_1.string,
    hashedSignature: utils_1.string,
    fullSignature: utils_1.string,
    abiJSON: exports.ABI_ErrorZ,
    default: utils_1.boolean.optional(),
});
exports.ABI_RowZ = zod_1.z.discriminatedUnion('type', [
    exports.ABI_RowConstructorZ,
    exports.ABI_RowEventZ,
    exports.ABI_RowFunctionZ,
    exports.ABI_RowReceiveZ,
    exports.ABI_RowFallbackZ,
    exports.ABI_RowErrorZ,
]);
//# sourceMappingURL=abi.js.map