import { DecodedTx } from './decoded';
import { RawTxData } from './rawData';
import { ChainSymbol } from './utils';
/**
 * Each address that was part of a transaction has its own interpretation of the transaction.
 * native tokens and gas number are denominated in their native token (ex: eth, not wei)
 */
export declare type Interpretation = {
    txHash: string;
    userAddress: string;
    contractName: string | null;
    contractAddress: string | null;
    actions: Action[];
    fromName?: string;
    toName?: string;
    exampleDescription: string;
    assetsSent: Asset[];
    assetsReceived: Asset[];
    chainSymbol: ChainSymbol;
    userName: string;
    counterpartyName: string | null;
    extra: Record<string, any>;
    reverted: true | null;
    gasPaid: string;
    timestamp: number | null;
};
export declare type ActivityData = {
    rawTxData: RawTxData;
    decodedTx: DecodedTx;
    interpretedData: Interpretation;
};
export declare const enum Action {
    unknown = "unknown",
    received = "received",
    sent = "sent",
    minted = "minted",
    burned = "burned",
    transferred = "transferred",
    deployed = "deployed",
    executed = "executed",
    bought = "bought",
    sold = "sold",
    /** Trading one non-native, non-stablecoin token for another */
    traded = "traded",
    /** Trading one stablecoin for another, or native token for the wrapped version (but not actually wrapping it using the wrapping contract itself) */
    swapped = "swapped",
    canceled = "canceled",
    transferredOwnership = "transferred ownership",
    receivedOwnership = "received ownership",
    addedLiquidity = "added liquidity",
    removedLiquidity = "removed liquidity",
    claimed = "claimed",
    contributed = "contributed",
    redeemed = "redeemed",
    approved = "approved",
    revoked = "revoked",
    gotAirdropped = "got airdropped",
    collected = "collected",
    multicall = "executed multiple actions",
    __NFTSALE__ = "__NFTSALE__",
    ______TODO______ = "______TODO______"
}
export declare const enum AssetType {
    ERC20 = "ERC20",
    ERC721 = "ERC721",
    ERC1155 = "ERC1155",
    LPToken = "LPToken",
    DEFAULT = "unknown",
    native = "native"
}
export declare type Asset = {
    type: AssetType;
    name: string | null;
    symbol: string | null;
    address: string;
    amount?: string;
    token0?: Asset;
    token1?: Asset;
    pair?: string;
    tokenId?: string;
};
