import { z } from 'zod';
export declare const TxResponseZ: z.ZodObject<{
    hash: z.ZodEffects<z.ZodString, string, string>;
    nonce: z.ZodNumber;
    blockHash: z.ZodEffects<z.ZodString, string, string>;
    blockNumber: z.ZodNumber;
    transactionIndex: z.ZodNumber;
    from: z.ZodEffects<z.ZodString, string, string>;
    to: z.ZodNullable<z.ZodEffects<z.ZodString, string, string>>;
    creates: z.ZodNullable<z.ZodEffects<z.ZodString, string, string>>;
    gasPrice: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    data: z.ZodEffects<z.ZodString, string, string>;
    chainId: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    data: string;
    value: import("ethers").BigNumber;
    nonce: number;
    blockHash: string;
    to: string | null;
    from: string;
    gasPrice: import("ethers").BigNumber;
    chainId: number;
    hash: string;
    blockNumber: number;
    transactionIndex: number;
    creates: string | null;
}, {
    data: string;
    value: string;
    nonce: number;
    blockHash: string;
    to: string | null;
    from: string;
    gasPrice: string;
    chainId: number;
    hash: string;
    blockNumber: number;
    transactionIndex: number;
    creates: string | null;
}>;
export declare type TxResponse = z.infer<typeof TxResponseZ>;
export declare const TxReceiptLogZ: z.ZodObject<{
    blockNumber: z.ZodNumber;
    blockHash: z.ZodString;
    transactionIndex: z.ZodNumber;
    removed: z.ZodBoolean;
    address: z.ZodEffects<z.ZodString, string, string>;
    data: z.ZodString;
    topics: z.ZodArray<z.ZodString, "many">;
    transactionHash: z.ZodString;
    logIndex: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    data: string;
    address: string;
    removed: boolean;
    blockHash: string;
    blockNumber: number;
    transactionIndex: number;
    topics: string[];
    transactionHash: string;
    logIndex: number;
}, {
    data: string;
    address: string;
    removed: boolean;
    blockHash: string;
    blockNumber: number;
    transactionIndex: number;
    topics: string[];
    transactionHash: string;
    logIndex: number;
}>;
export declare const TxReceiptZ: z.ZodObject<{
    transactionHash: z.ZodEffects<z.ZodString, string, string>;
    transactionIndex: z.ZodNumber;
    blockHash: z.ZodEffects<z.ZodString, string, string>;
    blockNumber: z.ZodNumber;
    cumulativeGasUsed: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    effectiveGasPrice: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>>;
    gasUsed: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    to: z.ZodNullable<z.ZodEffects<z.ZodString, string, string>>;
    from: z.ZodEffects<z.ZodString, string, string>;
    logs: z.ZodArray<z.ZodObject<{
        blockNumber: z.ZodNumber;
        blockHash: z.ZodString;
        transactionIndex: z.ZodNumber;
        removed: z.ZodBoolean;
        address: z.ZodEffects<z.ZodString, string, string>;
        data: z.ZodString;
        topics: z.ZodArray<z.ZodString, "many">;
        transactionHash: z.ZodString;
        logIndex: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        data: string;
        address: string;
        removed: boolean;
        blockHash: string;
        blockNumber: number;
        transactionIndex: number;
        topics: string[];
        transactionHash: string;
        logIndex: number;
    }, {
        data: string;
        address: string;
        removed: boolean;
        blockHash: string;
        blockNumber: number;
        transactionIndex: number;
        topics: string[];
        transactionHash: string;
        logIndex: number;
    }>, "many">;
    status: z.ZodNumber;
    timestamp: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    effectiveGasPrice?: import("ethers").BigNumber | undefined;
    status: number;
    blockHash: string;
    to: string | null;
    from: string;
    blockNumber: number;
    transactionIndex: number;
    transactionHash: string;
    cumulativeGasUsed: import("ethers").BigNumber;
    gasUsed: import("ethers").BigNumber;
    logs: {
        data: string;
        address: string;
        removed: boolean;
        blockHash: string;
        blockNumber: number;
        transactionIndex: number;
        topics: string[];
        transactionHash: string;
        logIndex: number;
    }[];
    timestamp: number;
}, {
    effectiveGasPrice?: string | undefined;
    status: number;
    blockHash: string;
    to: string | null;
    from: string;
    blockNumber: number;
    transactionIndex: number;
    transactionHash: string;
    cumulativeGasUsed: string;
    gasUsed: string;
    logs: {
        data: string;
        address: string;
        removed: boolean;
        blockHash: string;
        blockNumber: number;
        transactionIndex: number;
        topics: string[];
        transactionHash: string;
        logIndex: number;
    }[];
    timestamp: number;
}>;
export declare type TxReceipt = z.infer<typeof TxReceiptZ>;
declare const CreateTraceResultZ: z.ZodObject<{
    address: z.ZodNullable<z.ZodEffects<z.ZodString, string, string>>;
    code: z.ZodString;
    gasUsed: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
}, "strip", z.ZodTypeAny, {
    code: string;
    address: string | null;
    gasUsed: import("ethers").BigNumber;
}, {
    code: string;
    address: string | null;
    gasUsed: string;
}>;
declare const StandardTraceResultZ: z.ZodObject<{
    gasUsed: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    output: z.ZodString;
}, "strip", z.ZodTypeAny, {
    output: string;
    gasUsed: import("ethers").BigNumber;
}, {
    output: string;
    gasUsed: string;
}>;
declare const TraceResultZ: z.ZodUnion<[z.ZodObject<{
    gasUsed: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    output: z.ZodString;
}, "strip", z.ZodTypeAny, {
    output: string;
    gasUsed: import("ethers").BigNumber;
}, {
    output: string;
    gasUsed: string;
}>, z.ZodObject<{
    address: z.ZodNullable<z.ZodEffects<z.ZodString, string, string>>;
    code: z.ZodString;
    gasUsed: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
}, "strip", z.ZodTypeAny, {
    code: string;
    address: string | null;
    gasUsed: import("ethers").BigNumber;
}, {
    code: string;
    address: string | null;
    gasUsed: string;
}>]>;
export declare type CreateTraceResult = z.infer<typeof CreateTraceResultZ>;
export declare type StandardTraceResult = z.infer<typeof StandardTraceResultZ>;
export declare type TraceResult = z.infer<typeof TraceResultZ>;
declare const CallTraceActionZ: z.ZodObject<{
    callType: z.ZodEnum<["call", "delegatecall", "callcode", "staticcall"]>;
    from: z.ZodEffects<z.ZodString, string, string>;
    to: z.ZodEffects<z.ZodString, string, string>;
    gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    input: z.ZodString;
    value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
}, "strip", z.ZodTypeAny, {
    input: string;
    value: import("ethers").BigNumber;
    to: string;
    from: string;
    callType: "call" | "delegatecall" | "callcode" | "staticcall";
    gas: import("ethers").BigNumber;
}, {
    input: string;
    value: string;
    to: string;
    from: string;
    callType: "call" | "delegatecall" | "callcode" | "staticcall";
    gas: string;
}>;
declare const CreateTraceActionZ: z.ZodObject<{
    from: z.ZodEffects<z.ZodString, string, string>;
    gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    init: z.ZodString;
    value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
}, "strip", z.ZodTypeAny, {
    value: import("ethers").BigNumber;
    from: string;
    gas: import("ethers").BigNumber;
    init: string;
}, {
    value: string;
    from: string;
    gas: string;
    init: string;
}>;
declare const SuicideTraceActionZ: z.ZodObject<{
    address: z.ZodEffects<z.ZodString, string, string>;
    refundAddress: z.ZodEffects<z.ZodString, string, string>;
    balance: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
}, "strip", z.ZodTypeAny, {
    address: string;
    refundAddress: string;
    balance: import("ethers").BigNumber;
}, {
    address: string;
    refundAddress: string;
    balance: string;
}>;
declare const RewardTraceActionZ: z.ZodObject<{
    author: z.ZodEffects<z.ZodString, string, string>;
    rewardType: z.ZodString;
    value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
}, "strip", z.ZodTypeAny, {
    value: import("ethers").BigNumber;
    author: string;
    rewardType: string;
}, {
    value: string;
    author: string;
    rewardType: string;
}>;
declare const TraceActionZ: z.ZodUnion<[z.ZodObject<{
    callType: z.ZodEnum<["call", "delegatecall", "callcode", "staticcall"]>;
    from: z.ZodEffects<z.ZodString, string, string>;
    to: z.ZodEffects<z.ZodString, string, string>;
    gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    input: z.ZodString;
    value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
}, "strip", z.ZodTypeAny, {
    input: string;
    value: import("ethers").BigNumber;
    to: string;
    from: string;
    callType: "call" | "delegatecall" | "callcode" | "staticcall";
    gas: import("ethers").BigNumber;
}, {
    input: string;
    value: string;
    to: string;
    from: string;
    callType: "call" | "delegatecall" | "callcode" | "staticcall";
    gas: string;
}>, z.ZodObject<{
    from: z.ZodEffects<z.ZodString, string, string>;
    gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    init: z.ZodString;
    value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
}, "strip", z.ZodTypeAny, {
    value: import("ethers").BigNumber;
    from: string;
    gas: import("ethers").BigNumber;
    init: string;
}, {
    value: string;
    from: string;
    gas: string;
    init: string;
}>, z.ZodObject<{
    address: z.ZodEffects<z.ZodString, string, string>;
    refundAddress: z.ZodEffects<z.ZodString, string, string>;
    balance: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
}, "strip", z.ZodTypeAny, {
    address: string;
    refundAddress: string;
    balance: import("ethers").BigNumber;
}, {
    address: string;
    refundAddress: string;
    balance: string;
}>, z.ZodObject<{
    author: z.ZodEffects<z.ZodString, string, string>;
    rewardType: z.ZodString;
    value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
}, "strip", z.ZodTypeAny, {
    value: import("ethers").BigNumber;
    author: string;
    rewardType: string;
}, {
    value: string;
    author: string;
    rewardType: string;
}>]>;
export declare type CallTraceAction = z.infer<typeof CallTraceActionZ>;
export declare type CreateTraceAction = z.infer<typeof CreateTraceActionZ>;
export declare type SuicideTraceAction = z.infer<typeof SuicideTraceActionZ>;
export declare type RewardTraceAction = z.infer<typeof RewardTraceActionZ>;
export declare type TraceAction = z.infer<typeof TraceActionZ>;
export declare const TraceType: z.ZodEnum<["call", "create", "suicide", "reward"]>;
export declare const CallTraceLogZ: z.ZodObject<z.extendShape<{
    type: z.ZodEnum<["call", "create", "suicide", "reward"]>;
    action: z.ZodUnion<[z.ZodObject<{
        callType: z.ZodEnum<["call", "delegatecall", "callcode", "staticcall"]>;
        from: z.ZodEffects<z.ZodString, string, string>;
        to: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        input: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        input: string;
        value: import("ethers").BigNumber;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: import("ethers").BigNumber;
    }, {
        input: string;
        value: string;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: string;
    }>, z.ZodObject<{
        from: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        init: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        from: string;
        gas: import("ethers").BigNumber;
        init: string;
    }, {
        value: string;
        from: string;
        gas: string;
        init: string;
    }>, z.ZodObject<{
        address: z.ZodEffects<z.ZodString, string, string>;
        refundAddress: z.ZodEffects<z.ZodString, string, string>;
        balance: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        address: string;
        refundAddress: string;
        balance: import("ethers").BigNumber;
    }, {
        address: string;
        refundAddress: string;
        balance: string;
    }>, z.ZodObject<{
        author: z.ZodEffects<z.ZodString, string, string>;
        rewardType: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        author: string;
        rewardType: string;
    }, {
        value: string;
        author: string;
        rewardType: string;
    }>]>;
    blockHash: z.ZodEffects<z.ZodString, string, string>;
    blockNumber: z.ZodNullable<z.ZodNumber>;
    error: z.ZodOptional<z.ZodString>;
    subtraces: z.ZodNumber;
    traceAddress: z.ZodArray<z.ZodNumber, "many">;
    transactionHash: z.ZodEffects<z.ZodString, string, string>;
    transactionPosition: z.ZodNullable<z.ZodNumber>;
}, {
    type: z.ZodLiteral<"call">;
    action: z.ZodObject<{
        callType: z.ZodEnum<["call", "delegatecall", "callcode", "staticcall"]>;
        from: z.ZodEffects<z.ZodString, string, string>;
        to: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        input: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        input: string;
        value: import("ethers").BigNumber;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: import("ethers").BigNumber;
    }, {
        input: string;
        value: string;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: string;
    }>;
    result: z.ZodNullable<z.ZodOptional<z.ZodObject<{
        gasUsed: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        output: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        output: string;
        gasUsed: import("ethers").BigNumber;
    }, {
        output: string;
        gasUsed: string;
    }>>>;
}>, "strip", z.ZodTypeAny, {
    error?: string | undefined;
    result?: {
        output: string;
        gasUsed: import("ethers").BigNumber;
    } | null | undefined;
    type: "call";
    action: {
        input: string;
        value: import("ethers").BigNumber;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: import("ethers").BigNumber;
    };
    blockHash: string;
    blockNumber: number | null;
    transactionHash: string;
    subtraces: number;
    traceAddress: number[];
    transactionPosition: number | null;
}, {
    error?: string | undefined;
    result?: {
        output: string;
        gasUsed: string;
    } | null | undefined;
    type: "call";
    action: {
        input: string;
        value: string;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: string;
    };
    blockHash: string;
    blockNumber: number | null;
    transactionHash: string;
    subtraces: number;
    traceAddress: number[];
    transactionPosition: number | null;
}>;
export declare const CreateTraceLogZ: z.ZodObject<z.extendShape<{
    type: z.ZodEnum<["call", "create", "suicide", "reward"]>;
    action: z.ZodUnion<[z.ZodObject<{
        callType: z.ZodEnum<["call", "delegatecall", "callcode", "staticcall"]>;
        from: z.ZodEffects<z.ZodString, string, string>;
        to: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        input: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        input: string;
        value: import("ethers").BigNumber;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: import("ethers").BigNumber;
    }, {
        input: string;
        value: string;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: string;
    }>, z.ZodObject<{
        from: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        init: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        from: string;
        gas: import("ethers").BigNumber;
        init: string;
    }, {
        value: string;
        from: string;
        gas: string;
        init: string;
    }>, z.ZodObject<{
        address: z.ZodEffects<z.ZodString, string, string>;
        refundAddress: z.ZodEffects<z.ZodString, string, string>;
        balance: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        address: string;
        refundAddress: string;
        balance: import("ethers").BigNumber;
    }, {
        address: string;
        refundAddress: string;
        balance: string;
    }>, z.ZodObject<{
        author: z.ZodEffects<z.ZodString, string, string>;
        rewardType: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        author: string;
        rewardType: string;
    }, {
        value: string;
        author: string;
        rewardType: string;
    }>]>;
    blockHash: z.ZodEffects<z.ZodString, string, string>;
    blockNumber: z.ZodNullable<z.ZodNumber>;
    error: z.ZodOptional<z.ZodString>;
    subtraces: z.ZodNumber;
    traceAddress: z.ZodArray<z.ZodNumber, "many">;
    transactionHash: z.ZodEffects<z.ZodString, string, string>;
    transactionPosition: z.ZodNullable<z.ZodNumber>;
}, {
    type: z.ZodLiteral<"create">;
    action: z.ZodObject<{
        from: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        init: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        from: string;
        gas: import("ethers").BigNumber;
        init: string;
    }, {
        value: string;
        from: string;
        gas: string;
        init: string;
    }>;
    result: z.ZodNullable<z.ZodOptional<z.ZodObject<{
        address: z.ZodNullable<z.ZodEffects<z.ZodString, string, string>>;
        code: z.ZodString;
        gasUsed: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        code: string;
        address: string | null;
        gasUsed: import("ethers").BigNumber;
    }, {
        code: string;
        address: string | null;
        gasUsed: string;
    }>>>;
}>, "strip", z.ZodTypeAny, {
    error?: string | undefined;
    result?: {
        code: string;
        address: string | null;
        gasUsed: import("ethers").BigNumber;
    } | null | undefined;
    type: "create";
    action: {
        value: import("ethers").BigNumber;
        from: string;
        gas: import("ethers").BigNumber;
        init: string;
    };
    blockHash: string;
    blockNumber: number | null;
    transactionHash: string;
    subtraces: number;
    traceAddress: number[];
    transactionPosition: number | null;
}, {
    error?: string | undefined;
    result?: {
        code: string;
        address: string | null;
        gasUsed: string;
    } | null | undefined;
    type: "create";
    action: {
        value: string;
        from: string;
        gas: string;
        init: string;
    };
    blockHash: string;
    blockNumber: number | null;
    transactionHash: string;
    subtraces: number;
    traceAddress: number[];
    transactionPosition: number | null;
}>;
export declare const SuicideTraceLogZ: z.ZodObject<z.extendShape<{
    type: z.ZodEnum<["call", "create", "suicide", "reward"]>;
    action: z.ZodUnion<[z.ZodObject<{
        callType: z.ZodEnum<["call", "delegatecall", "callcode", "staticcall"]>;
        from: z.ZodEffects<z.ZodString, string, string>;
        to: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        input: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        input: string;
        value: import("ethers").BigNumber;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: import("ethers").BigNumber;
    }, {
        input: string;
        value: string;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: string;
    }>, z.ZodObject<{
        from: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        init: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        from: string;
        gas: import("ethers").BigNumber;
        init: string;
    }, {
        value: string;
        from: string;
        gas: string;
        init: string;
    }>, z.ZodObject<{
        address: z.ZodEffects<z.ZodString, string, string>;
        refundAddress: z.ZodEffects<z.ZodString, string, string>;
        balance: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        address: string;
        refundAddress: string;
        balance: import("ethers").BigNumber;
    }, {
        address: string;
        refundAddress: string;
        balance: string;
    }>, z.ZodObject<{
        author: z.ZodEffects<z.ZodString, string, string>;
        rewardType: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        author: string;
        rewardType: string;
    }, {
        value: string;
        author: string;
        rewardType: string;
    }>]>;
    blockHash: z.ZodEffects<z.ZodString, string, string>;
    blockNumber: z.ZodNullable<z.ZodNumber>;
    error: z.ZodOptional<z.ZodString>;
    subtraces: z.ZodNumber;
    traceAddress: z.ZodArray<z.ZodNumber, "many">;
    transactionHash: z.ZodEffects<z.ZodString, string, string>;
    transactionPosition: z.ZodNullable<z.ZodNumber>;
}, {
    type: z.ZodLiteral<"suicide">;
    action: z.ZodObject<{
        address: z.ZodEffects<z.ZodString, string, string>;
        refundAddress: z.ZodEffects<z.ZodString, string, string>;
        balance: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        address: string;
        refundAddress: string;
        balance: import("ethers").BigNumber;
    }, {
        address: string;
        refundAddress: string;
        balance: string;
    }>;
    result: z.ZodNullable<z.ZodOptional<z.ZodObject<{
        gasUsed: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        output: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        output: string;
        gasUsed: import("ethers").BigNumber;
    }, {
        output: string;
        gasUsed: string;
    }>>>;
}>, "strip", z.ZodTypeAny, {
    error?: string | undefined;
    result?: {
        output: string;
        gasUsed: import("ethers").BigNumber;
    } | null | undefined;
    type: "suicide";
    action: {
        address: string;
        refundAddress: string;
        balance: import("ethers").BigNumber;
    };
    blockHash: string;
    blockNumber: number | null;
    transactionHash: string;
    subtraces: number;
    traceAddress: number[];
    transactionPosition: number | null;
}, {
    error?: string | undefined;
    result?: {
        output: string;
        gasUsed: string;
    } | null | undefined;
    type: "suicide";
    action: {
        address: string;
        refundAddress: string;
        balance: string;
    };
    blockHash: string;
    blockNumber: number | null;
    transactionHash: string;
    subtraces: number;
    traceAddress: number[];
    transactionPosition: number | null;
}>;
export declare const RewardTraceLogZ: z.ZodObject<z.extendShape<{
    type: z.ZodEnum<["call", "create", "suicide", "reward"]>;
    action: z.ZodUnion<[z.ZodObject<{
        callType: z.ZodEnum<["call", "delegatecall", "callcode", "staticcall"]>;
        from: z.ZodEffects<z.ZodString, string, string>;
        to: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        input: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        input: string;
        value: import("ethers").BigNumber;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: import("ethers").BigNumber;
    }, {
        input: string;
        value: string;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: string;
    }>, z.ZodObject<{
        from: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        init: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        from: string;
        gas: import("ethers").BigNumber;
        init: string;
    }, {
        value: string;
        from: string;
        gas: string;
        init: string;
    }>, z.ZodObject<{
        address: z.ZodEffects<z.ZodString, string, string>;
        refundAddress: z.ZodEffects<z.ZodString, string, string>;
        balance: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        address: string;
        refundAddress: string;
        balance: import("ethers").BigNumber;
    }, {
        address: string;
        refundAddress: string;
        balance: string;
    }>, z.ZodObject<{
        author: z.ZodEffects<z.ZodString, string, string>;
        rewardType: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        author: string;
        rewardType: string;
    }, {
        value: string;
        author: string;
        rewardType: string;
    }>]>;
    blockHash: z.ZodEffects<z.ZodString, string, string>;
    blockNumber: z.ZodNullable<z.ZodNumber>;
    error: z.ZodOptional<z.ZodString>;
    subtraces: z.ZodNumber;
    traceAddress: z.ZodArray<z.ZodNumber, "many">;
    transactionHash: z.ZodEffects<z.ZodString, string, string>;
    transactionPosition: z.ZodNullable<z.ZodNumber>;
}, {
    type: z.ZodLiteral<"reward">;
    action: z.ZodObject<{
        author: z.ZodEffects<z.ZodString, string, string>;
        rewardType: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        author: string;
        rewardType: string;
    }, {
        value: string;
        author: string;
        rewardType: string;
    }>;
    result: z.ZodNullable<z.ZodOptional<z.ZodObject<{
        gasUsed: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        output: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        output: string;
        gasUsed: import("ethers").BigNumber;
    }, {
        output: string;
        gasUsed: string;
    }>>>;
}>, "strip", z.ZodTypeAny, {
    error?: string | undefined;
    result?: {
        output: string;
        gasUsed: import("ethers").BigNumber;
    } | null | undefined;
    type: "reward";
    action: {
        value: import("ethers").BigNumber;
        author: string;
        rewardType: string;
    };
    blockHash: string;
    blockNumber: number | null;
    transactionHash: string;
    subtraces: number;
    traceAddress: number[];
    transactionPosition: number | null;
}, {
    error?: string | undefined;
    result?: {
        output: string;
        gasUsed: string;
    } | null | undefined;
    type: "reward";
    action: {
        value: string;
        author: string;
        rewardType: string;
    };
    blockHash: string;
    blockNumber: number | null;
    transactionHash: string;
    subtraces: number;
    traceAddress: number[];
    transactionPosition: number | null;
}>;
export declare const TraceLogZ: z.ZodDiscriminatedUnion<"type", z.Primitive, z.ZodObject<z.extendShape<{
    type: z.ZodEnum<["call", "create", "suicide", "reward"]>;
    action: z.ZodUnion<[z.ZodObject<{
        callType: z.ZodEnum<["call", "delegatecall", "callcode", "staticcall"]>;
        from: z.ZodEffects<z.ZodString, string, string>;
        to: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        input: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        input: string;
        value: import("ethers").BigNumber;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: import("ethers").BigNumber;
    }, {
        input: string;
        value: string;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: string;
    }>, z.ZodObject<{
        from: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        init: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        from: string;
        gas: import("ethers").BigNumber;
        init: string;
    }, {
        value: string;
        from: string;
        gas: string;
        init: string;
    }>, z.ZodObject<{
        address: z.ZodEffects<z.ZodString, string, string>;
        refundAddress: z.ZodEffects<z.ZodString, string, string>;
        balance: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        address: string;
        refundAddress: string;
        balance: import("ethers").BigNumber;
    }, {
        address: string;
        refundAddress: string;
        balance: string;
    }>, z.ZodObject<{
        author: z.ZodEffects<z.ZodString, string, string>;
        rewardType: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        author: string;
        rewardType: string;
    }, {
        value: string;
        author: string;
        rewardType: string;
    }>]>;
    blockHash: z.ZodEffects<z.ZodString, string, string>;
    blockNumber: z.ZodNullable<z.ZodNumber>;
    error: z.ZodOptional<z.ZodString>;
    subtraces: z.ZodNumber;
    traceAddress: z.ZodArray<z.ZodNumber, "many">;
    transactionHash: z.ZodEffects<z.ZodString, string, string>;
    transactionPosition: z.ZodNullable<z.ZodNumber>;
}, {
    type: z.ZodLiteral<"call">;
    action: z.ZodObject<{
        callType: z.ZodEnum<["call", "delegatecall", "callcode", "staticcall"]>;
        from: z.ZodEffects<z.ZodString, string, string>;
        to: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        input: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        input: string;
        value: import("ethers").BigNumber;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: import("ethers").BigNumber;
    }, {
        input: string;
        value: string;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: string;
    }>;
    result: z.ZodNullable<z.ZodOptional<z.ZodObject<{
        gasUsed: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        output: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        output: string;
        gasUsed: import("ethers").BigNumber;
    }, {
        output: string;
        gasUsed: string;
    }>>>;
}>, "strip", z.ZodTypeAny, {
    error?: string | undefined;
    result?: {
        output: string;
        gasUsed: import("ethers").BigNumber;
    } | null | undefined;
    type: "call";
    action: {
        input: string;
        value: import("ethers").BigNumber;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: import("ethers").BigNumber;
    };
    blockHash: string;
    blockNumber: number | null;
    transactionHash: string;
    subtraces: number;
    traceAddress: number[];
    transactionPosition: number | null;
}, {
    error?: string | undefined;
    result?: {
        output: string;
        gasUsed: string;
    } | null | undefined;
    type: "call";
    action: {
        input: string;
        value: string;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: string;
    };
    blockHash: string;
    blockNumber: number | null;
    transactionHash: string;
    subtraces: number;
    traceAddress: number[];
    transactionPosition: number | null;
}> | z.ZodObject<z.extendShape<{
    type: z.ZodEnum<["call", "create", "suicide", "reward"]>;
    action: z.ZodUnion<[z.ZodObject<{
        callType: z.ZodEnum<["call", "delegatecall", "callcode", "staticcall"]>;
        from: z.ZodEffects<z.ZodString, string, string>;
        to: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        input: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        input: string;
        value: import("ethers").BigNumber;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: import("ethers").BigNumber;
    }, {
        input: string;
        value: string;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: string;
    }>, z.ZodObject<{
        from: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        init: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        from: string;
        gas: import("ethers").BigNumber;
        init: string;
    }, {
        value: string;
        from: string;
        gas: string;
        init: string;
    }>, z.ZodObject<{
        address: z.ZodEffects<z.ZodString, string, string>;
        refundAddress: z.ZodEffects<z.ZodString, string, string>;
        balance: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        address: string;
        refundAddress: string;
        balance: import("ethers").BigNumber;
    }, {
        address: string;
        refundAddress: string;
        balance: string;
    }>, z.ZodObject<{
        author: z.ZodEffects<z.ZodString, string, string>;
        rewardType: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        author: string;
        rewardType: string;
    }, {
        value: string;
        author: string;
        rewardType: string;
    }>]>;
    blockHash: z.ZodEffects<z.ZodString, string, string>;
    blockNumber: z.ZodNullable<z.ZodNumber>;
    error: z.ZodOptional<z.ZodString>;
    subtraces: z.ZodNumber;
    traceAddress: z.ZodArray<z.ZodNumber, "many">;
    transactionHash: z.ZodEffects<z.ZodString, string, string>;
    transactionPosition: z.ZodNullable<z.ZodNumber>;
}, {
    type: z.ZodLiteral<"create">;
    action: z.ZodObject<{
        from: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        init: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        from: string;
        gas: import("ethers").BigNumber;
        init: string;
    }, {
        value: string;
        from: string;
        gas: string;
        init: string;
    }>;
    result: z.ZodNullable<z.ZodOptional<z.ZodObject<{
        address: z.ZodNullable<z.ZodEffects<z.ZodString, string, string>>;
        code: z.ZodString;
        gasUsed: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        code: string;
        address: string | null;
        gasUsed: import("ethers").BigNumber;
    }, {
        code: string;
        address: string | null;
        gasUsed: string;
    }>>>;
}>, "strip", z.ZodTypeAny, {
    error?: string | undefined;
    result?: {
        code: string;
        address: string | null;
        gasUsed: import("ethers").BigNumber;
    } | null | undefined;
    type: "create";
    action: {
        value: import("ethers").BigNumber;
        from: string;
        gas: import("ethers").BigNumber;
        init: string;
    };
    blockHash: string;
    blockNumber: number | null;
    transactionHash: string;
    subtraces: number;
    traceAddress: number[];
    transactionPosition: number | null;
}, {
    error?: string | undefined;
    result?: {
        code: string;
        address: string | null;
        gasUsed: string;
    } | null | undefined;
    type: "create";
    action: {
        value: string;
        from: string;
        gas: string;
        init: string;
    };
    blockHash: string;
    blockNumber: number | null;
    transactionHash: string;
    subtraces: number;
    traceAddress: number[];
    transactionPosition: number | null;
}> | z.ZodObject<z.extendShape<{
    type: z.ZodEnum<["call", "create", "suicide", "reward"]>;
    action: z.ZodUnion<[z.ZodObject<{
        callType: z.ZodEnum<["call", "delegatecall", "callcode", "staticcall"]>;
        from: z.ZodEffects<z.ZodString, string, string>;
        to: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        input: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        input: string;
        value: import("ethers").BigNumber;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: import("ethers").BigNumber;
    }, {
        input: string;
        value: string;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: string;
    }>, z.ZodObject<{
        from: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        init: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        from: string;
        gas: import("ethers").BigNumber;
        init: string;
    }, {
        value: string;
        from: string;
        gas: string;
        init: string;
    }>, z.ZodObject<{
        address: z.ZodEffects<z.ZodString, string, string>;
        refundAddress: z.ZodEffects<z.ZodString, string, string>;
        balance: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        address: string;
        refundAddress: string;
        balance: import("ethers").BigNumber;
    }, {
        address: string;
        refundAddress: string;
        balance: string;
    }>, z.ZodObject<{
        author: z.ZodEffects<z.ZodString, string, string>;
        rewardType: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        author: string;
        rewardType: string;
    }, {
        value: string;
        author: string;
        rewardType: string;
    }>]>;
    blockHash: z.ZodEffects<z.ZodString, string, string>;
    blockNumber: z.ZodNullable<z.ZodNumber>;
    error: z.ZodOptional<z.ZodString>;
    subtraces: z.ZodNumber;
    traceAddress: z.ZodArray<z.ZodNumber, "many">;
    transactionHash: z.ZodEffects<z.ZodString, string, string>;
    transactionPosition: z.ZodNullable<z.ZodNumber>;
}, {
    type: z.ZodLiteral<"suicide">;
    action: z.ZodObject<{
        address: z.ZodEffects<z.ZodString, string, string>;
        refundAddress: z.ZodEffects<z.ZodString, string, string>;
        balance: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        address: string;
        refundAddress: string;
        balance: import("ethers").BigNumber;
    }, {
        address: string;
        refundAddress: string;
        balance: string;
    }>;
    result: z.ZodNullable<z.ZodOptional<z.ZodObject<{
        gasUsed: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        output: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        output: string;
        gasUsed: import("ethers").BigNumber;
    }, {
        output: string;
        gasUsed: string;
    }>>>;
}>, "strip", z.ZodTypeAny, {
    error?: string | undefined;
    result?: {
        output: string;
        gasUsed: import("ethers").BigNumber;
    } | null | undefined;
    type: "suicide";
    action: {
        address: string;
        refundAddress: string;
        balance: import("ethers").BigNumber;
    };
    blockHash: string;
    blockNumber: number | null;
    transactionHash: string;
    subtraces: number;
    traceAddress: number[];
    transactionPosition: number | null;
}, {
    error?: string | undefined;
    result?: {
        output: string;
        gasUsed: string;
    } | null | undefined;
    type: "suicide";
    action: {
        address: string;
        refundAddress: string;
        balance: string;
    };
    blockHash: string;
    blockNumber: number | null;
    transactionHash: string;
    subtraces: number;
    traceAddress: number[];
    transactionPosition: number | null;
}> | z.ZodObject<z.extendShape<{
    type: z.ZodEnum<["call", "create", "suicide", "reward"]>;
    action: z.ZodUnion<[z.ZodObject<{
        callType: z.ZodEnum<["call", "delegatecall", "callcode", "staticcall"]>;
        from: z.ZodEffects<z.ZodString, string, string>;
        to: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        input: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        input: string;
        value: import("ethers").BigNumber;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: import("ethers").BigNumber;
    }, {
        input: string;
        value: string;
        to: string;
        from: string;
        callType: "call" | "delegatecall" | "callcode" | "staticcall";
        gas: string;
    }>, z.ZodObject<{
        from: z.ZodEffects<z.ZodString, string, string>;
        gas: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        init: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        from: string;
        gas: import("ethers").BigNumber;
        init: string;
    }, {
        value: string;
        from: string;
        gas: string;
        init: string;
    }>, z.ZodObject<{
        address: z.ZodEffects<z.ZodString, string, string>;
        refundAddress: z.ZodEffects<z.ZodString, string, string>;
        balance: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        address: string;
        refundAddress: string;
        balance: import("ethers").BigNumber;
    }, {
        address: string;
        refundAddress: string;
        balance: string;
    }>, z.ZodObject<{
        author: z.ZodEffects<z.ZodString, string, string>;
        rewardType: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        author: string;
        rewardType: string;
    }, {
        value: string;
        author: string;
        rewardType: string;
    }>]>;
    blockHash: z.ZodEffects<z.ZodString, string, string>;
    blockNumber: z.ZodNullable<z.ZodNumber>;
    error: z.ZodOptional<z.ZodString>;
    subtraces: z.ZodNumber;
    traceAddress: z.ZodArray<z.ZodNumber, "many">;
    transactionHash: z.ZodEffects<z.ZodString, string, string>;
    transactionPosition: z.ZodNullable<z.ZodNumber>;
}, {
    type: z.ZodLiteral<"reward">;
    action: z.ZodObject<{
        author: z.ZodEffects<z.ZodString, string, string>;
        rewardType: z.ZodString;
        value: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
    }, "strip", z.ZodTypeAny, {
        value: import("ethers").BigNumber;
        author: string;
        rewardType: string;
    }, {
        value: string;
        author: string;
        rewardType: string;
    }>;
    result: z.ZodNullable<z.ZodOptional<z.ZodObject<{
        gasUsed: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, import("ethers").BigNumber, string>;
        output: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        output: string;
        gasUsed: import("ethers").BigNumber;
    }, {
        output: string;
        gasUsed: string;
    }>>>;
}>, "strip", z.ZodTypeAny, {
    error?: string | undefined;
    result?: {
        output: string;
        gasUsed: import("ethers").BigNumber;
    } | null | undefined;
    type: "reward";
    action: {
        value: import("ethers").BigNumber;
        author: string;
        rewardType: string;
    };
    blockHash: string;
    blockNumber: number | null;
    transactionHash: string;
    subtraces: number;
    traceAddress: number[];
    transactionPosition: number | null;
}, {
    error?: string | undefined;
    result?: {
        output: string;
        gasUsed: string;
    } | null | undefined;
    type: "reward";
    action: {
        value: string;
        author: string;
        rewardType: string;
    };
    blockHash: string;
    blockNumber: number | null;
    transactionHash: string;
    subtraces: number;
    traceAddress: number[];
    transactionPosition: number | null;
}>>;
export declare type TraceLog = z.infer<typeof TraceLogZ>;
export declare type CallTraceLog = z.infer<typeof CallTraceLogZ>;
export declare type RawTxData = {
    txResponse: TxResponse;
    txReceipt: TxReceipt;
    txTrace: TraceLog[];
};
export {};
