"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TraceLogZ = exports.RewardTraceLogZ = exports.SuicideTraceLogZ = exports.CreateTraceLogZ = exports.CallTraceLogZ = exports.TraceType = exports.TxReceiptZ = exports.TxReceiptLogZ = exports.TxResponseZ = void 0;
const zod_1 = require("zod");
const utils_1 = require("../interfaces/utils");
// type EVMTransaction struct {
// 	Hash               string                 `json:"hash"`
// 	Nonce              int                    `json:"nonce"`
// 	BlockHash          string                 `json:"blockHash"`
// 	BlockNumber        *int                   `json:"blockNumber"`
// 	TransactionIndex   *int                   `json:"transactionIndex"`
// 	From               string                 `json:"from"`
// 	To                 string                 `json:"to"`
// 	Value              big.Int                `json:"value"`
// 	Gas                int                    `json:"gas"`
// 	GasPrice           big.Int                `json:"gasPrice"`
// 	Input              string                 `json:"input"`
// 	TransactionReceipt *EVMTransactionReceipt `json:"transactionReceipt"`
// 	Trace              *EVMTrace              `json:"trace"`
// }
// type EVMTransactionReceipt struct {
// 	TransactionHash   string    `json:"transactionHash"`
// 	TransactionIndex  int       `json:"transactionIndex"`
// 	BlockHash         string    `json:"blockHash"`
// 	BlockNumber       int       `json:"blockNumber"`
// 	CumulativeGasUsed int       `json:"cumulativeGasUsed"`
// 	GasUsed           int       `json:"gasUsed"`
// 	ContractAddress   string    `json:"contractAddress"`
// 	Logs              []*EVMLog `json:"logs"`
// 	LogsBloom         string    `json:"logsBloom"`
// 	Root              string    `json:"root"`
// 	Status            string    `json:"status"`
// }
exports.TxResponseZ = zod_1.z.object({
    hash: utils_1.HashZ,
    nonce: utils_1.int,
    blockHash: utils_1.HashZ,
    blockNumber: utils_1.int,
    transactionIndex: utils_1.int,
    from: utils_1.AddressZ,
    to: utils_1.optionalAddressZ,
    creates: utils_1.optionalAddressZ,
    gasPrice: utils_1.BigNumberZ,
    value: utils_1.BigNumberZ,
    data: utils_1.HashZ,
    chainId: utils_1.int,
});
exports.TxReceiptLogZ = zod_1.z.object({
    blockNumber: utils_1.number,
    blockHash: utils_1.string,
    transactionIndex: utils_1.number,
    removed: utils_1.boolean,
    address: utils_1.AddressZ,
    data: utils_1.string,
    topics: zod_1.z.array(utils_1.string),
    transactionHash: utils_1.string,
    logIndex: utils_1.number,
});
exports.TxReceiptZ = zod_1.z.object({
    transactionHash: utils_1.HashZ,
    transactionIndex: utils_1.int,
    blockHash: utils_1.HashZ,
    blockNumber: utils_1.int,
    cumulativeGasUsed: utils_1.BigNumberZ,
    effectiveGasPrice: utils_1.OptionalBigNumberZ,
    gasUsed: utils_1.BigNumberZ,
    to: utils_1.optionalAddressZ,
    from: utils_1.AddressZ,
    logs: zod_1.z.array(exports.TxReceiptLogZ),
    status: utils_1.number,
    timestamp: utils_1.number,
});
const CreateTraceResultZ = zod_1.z.object({
    address: utils_1.AddressZ.nullable(),
    code: utils_1.string,
    gasUsed: utils_1.BigNumberZ,
});
const StandardTraceResultZ = zod_1.z.object({
    gasUsed: utils_1.BigNumberZ,
    output: utils_1.string, // bytes
});
const TraceResultZ = zod_1.z.union([StandardTraceResultZ, CreateTraceResultZ]);
// https://ethereum.stackexchange.com/questions/63743/whats-the-difference-between-type-and-calltype-in-parity-trace
// https://github.com/openethereum/parity-ethereum/blob/master/rpc/src/v1/types/trace.rs#L246
const TraceActionCallTypeZ = zod_1.z.enum(['call', 'delegatecall', 'callcode', 'staticcall']);
// const TraceActionCreateTypeZ = z.enum(['create', 'create2'])
// const TraceActionSuicideTypeZ = z.enum(['suicide'])
// const TraceACtionRewardTypeZ = z.enum(['block', 'uncle', 'emptyStep', 'external'])
const CallTraceActionZ = zod_1.z.object({
    callType: TraceActionCallTypeZ,
    from: utils_1.AddressZ,
    to: utils_1.AddressZ,
    gas: utils_1.BigNumberZ,
    input: utils_1.string,
    value: utils_1.BigNumberZ,
});
const CreateTraceActionZ = zod_1.z.object({
    from: utils_1.AddressZ,
    gas: utils_1.BigNumberZ,
    init: utils_1.string,
    value: utils_1.BigNumberZ,
});
const SuicideTraceActionZ = zod_1.z.object({
    address: utils_1.AddressZ,
    refundAddress: utils_1.AddressZ,
    balance: utils_1.BigNumberZ,
});
const RewardTraceActionZ = zod_1.z.object({
    author: utils_1.AddressZ,
    rewardType: utils_1.string,
    value: utils_1.BigNumberZ,
});
const TraceActionZ = zod_1.z.union([CallTraceActionZ, CreateTraceActionZ, SuicideTraceActionZ, RewardTraceActionZ]);
exports.TraceType = zod_1.z.enum(['call', 'create', 'suicide', 'reward']);
const traceLogAbstractZ = zod_1.z.object({
    type: exports.TraceType,
    action: TraceActionZ,
    blockHash: utils_1.HashZ,
    blockNumber: utils_1.nullableInt,
    error: utils_1.string.optional(),
    subtraces: utils_1.number,
    traceAddress: zod_1.z.array(utils_1.number),
    transactionHash: utils_1.HashZ,
    transactionPosition: utils_1.nullableInt,
});
exports.CallTraceLogZ = traceLogAbstractZ.extend({
    type: zod_1.z.literal(exports.TraceType.Enum.call),
    action: CallTraceActionZ,
    result: StandardTraceResultZ.optional().nullable(),
});
exports.CreateTraceLogZ = traceLogAbstractZ.extend({
    type: zod_1.z.literal(exports.TraceType.Enum.create),
    action: CreateTraceActionZ,
    result: CreateTraceResultZ.optional().nullable(),
});
exports.SuicideTraceLogZ = traceLogAbstractZ.extend({
    type: zod_1.z.literal(exports.TraceType.Enum.suicide),
    action: SuicideTraceActionZ,
    result: StandardTraceResultZ.optional().nullable(),
});
exports.RewardTraceLogZ = traceLogAbstractZ.extend({
    type: zod_1.z.literal(exports.TraceType.Enum.reward),
    action: RewardTraceActionZ,
    result: StandardTraceResultZ.optional().nullable(),
});
exports.TraceLogZ = zod_1.z.discriminatedUnion('type', [
    exports.CallTraceLogZ,
    exports.CreateTraceLogZ,
    exports.SuicideTraceLogZ,
    exports.RewardTraceLogZ,
]);
//# sourceMappingURL=rawData.js.map