import { Network } from '@alch/alchemy-sdk';
import { BigNumber } from 'ethers';
import { z } from 'zod';
export declare const addressRegex: RegExp;
export declare const hashRegex: RegExp;
export declare const toLowercaseFn: (x: string) => string;
export declare const number: z.ZodNumber;
export declare const int: z.ZodNumber;
export declare const nullableInt: z.ZodNullable<z.ZodNumber>;
export declare const string: z.ZodString;
export declare const boolean: z.ZodBoolean;
export declare const AddressZ: z.ZodEffects<z.ZodString, string, string>;
export declare const optionalAddressZ: z.ZodNullable<z.ZodEffects<z.ZodString, string, string>>;
export declare const HashZ: z.ZodEffects<z.ZodString, string, string>;
export declare const BigNumberZ: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, BigNumber, string>;
export declare const OptionalBigNumberZ: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, BigNumber, string>>;
export declare const functionSchema: z.ZodFunction<z.ZodTuple<[z.ZodEffects<z.ZodString, string, string>], z.ZodUnknown>, z.ZodEffects<z.ZodString, string, string>>;
export declare const enum ChainSymbol {
    ETH = "ETH",
    MATIC = "MATIC"
}
export declare type Chain = {
    /** If this transaction is from an EVM-compatible chain. This it true for all, currently */
    EVM: boolean;
    /** The chain's id. ETH=1, MATIC=137 */
    id: number;
    /** The chain's colloquial name. Ethereum, Polygon */
    name: string;
    /** The chain's symbol. ETH, MATIC */
    symbol: ChainSymbol;
    /** If this chain is a testnet. */
    testnet: boolean;
    /** The block explorer URL for this chain. https://etherscan.io/ */
    blockExplorerUrl: string;
    /** The singleton contract address for the wrapped version of the native token. Need to change the variable name */
    wethAddress: string;
    /** The singleton contract address for USDC */
    usdcAddress: string;
    /** The singleton contract address for USDT */
    usdtAddress: string;
    /** The singleton contract address for DAI */
    daiAddress: string;
    /** The singleton contract address for the native asset */
    nativeAssetAddress: string;
    /** alchemy network string */
    alchemyNetworkString: Network;
};
/** Map of EVM chain names to an object with Chain metadata */
export declare type Chains = Record<string, Chain>;
