import { ABI_Event, ABI_Function, ABI_ItemUnfiltered, ABI_Row, EventSigOptions as EventSigMap } from '../interfaces/abi';
import { AddressNameData, ContractData, DecodedTx } from '../interfaces/decoded';
import { Interpretation } from '../interfaces/interpreted';
export declare abstract class DatabaseInterface {
    abstract getManyContractDataMap(contractAddresses: string[]): Promise<Record<string, ContractData | null>>;
    abstract addOrUpdateManyContractData(contractDataArr: ContractData[]): Promise<void>;
    /** Contracts often don't have their full ABI shared, but we can infer it using a signature table when we see a contract using that ABI */
    abstract addOrUpdateManyABI(abiArr: ABI_Row[]): Promise<void | any>;
    /** Returns an array b/c there might be more than one full signature per hex signature. hex<-->hashable is 1:1*/
    abstract getABIsForHexSignature(hexSignature: string): Promise<ABI_ItemUnfiltered[]>;
    abstract getFirstABIForHexSignature(hexSignature: string): Promise<ABI_ItemUnfiltered | null>;
    abstract getEventABIsForHexSignature(hexSignature: string): Promise<ABI_Event[]>;
    abstract getManyEventABIsForHexSignatures(hexSignatures: string[]): Promise<EventSigMap>;
    abstract getFunctionABIsForHexSignature(hexSignature: string): Promise<ABI_Function[]>;
    abstract getManyDecodedTxMap(txHashes: string[]): Promise<Record<string, DecodedTx | null>>;
    abstract addOrUpdateManyDecodedTx(decodedDataArr: DecodedTx[]): Promise<void>;
    abstract deleteManyDecodedTxs(txHashes: string[]): Promise<number>;
    abstract getManyNameDataMap(names: string[]): Promise<Record<string, AddressNameData | null>>;
    abstract getManyEntityMap(addresses: string[]): Promise<Record<string, string | null>>;
    abstract getEntityByAddress(address: string): Promise<string | null>;
}
export declare class NullDatabaseInterface extends DatabaseInterface {
    getContractDataForContract(contractAddress: string): Promise<ContractData | null>;
    getManyContractDataMap(contractAddresses: string[]): Promise<Record<string, ContractData | null>>;
    addOrUpdateContractData(contractData: ContractData): Promise<void>;
    addOrUpdateManyContractData(contractDataArr: ContractData[]): Promise<void>;
    /** Contracts often don't have their full ABI shared, but we can infer it using a signature table when we see a contract using that ABI */
    AppendABIsToContractData(contractAddress: string, abi: ABI_ItemUnfiltered[]): Promise<void>;
    addOrUpdateABI(abiArr: ABI_Row): Promise<void>;
    addOrUpdateManyABI(abiArr: ABI_Row[]): Promise<void | any>;
    /** Returns an array b/c there might be more than one full signature per hex signature. hex<-->hashable is 1:1*/
    getABIsForHexSignature(hexSignature: string): Promise<ABI_ItemUnfiltered[]>;
    getEventABIsForHexSignature(hexSignature: string): Promise<ABI_Event[]>;
    getManyEventABIsForHexSignatures(hexSignatures: string[]): Promise<EventSigMap>;
    getFunctionABIsForHexSignature(hexSignature: string): Promise<ABI_Function[]>;
    getFirstABIForHexSignature(hexSignature: string): Promise<ABI_ItemUnfiltered | null>;
    getABIRowsForHexSignature(hexSignature: string): Promise<ABI_Row[] | null>;
    getFirstABIRowForHexSignature(hexSignature: string): Promise<ABI_Row | null>;
    getEntityByAddress(address: string): Promise<string | null>;
    getDecodedTx(txHash: string): Promise<DecodedTx | null>;
    getManyDecodedTxMap(txHashes: string[]): Promise<Record<string, DecodedTx | null>>;
    getManyNameDataMap(addresses: string[]): Promise<Record<string, AddressNameData | null>>;
    getManyEntityMap(addresses: string[]): Promise<Record<string, string | null>>;
    addOrUpdateManyDecodedTx(decodedData: DecodedTx[]): Promise<void>;
    deleteManyDecodedTxs(txHashes: string[]): Promise<number>;
    addOrUpdateInterpretedData(interpretedData: Interpretation): Promise<void>;
    addOrUpdateManyInterpretedData(interpretedDataArr: Interpretation[]): Promise<void>;
    getInterpretedData(txHash: string, userAddress: string | null): Promise<Interpretation | null>;
    getManyInterpretedData(txHashes: string[], userAddress: string | null): Promise<Array<Interpretation | null> | null>;
    getAllInterpretationsForTxHash(txHash: string): Promise<Interpretation[] | null>;
    getAllInterpretationsForAddress(address: string): Promise<Interpretation[] | null>;
}
