import { DatabaseInterface } from './DatabaseInterface';
import { Log } from '@ethersproject/providers';
import { ABI_Event, ABI_Function, ABI_Item, ABI_Row, EventSigOptions } from '../interfaces/abi';
import { ContractData, RawDecodedCallData, RawDecodedLog } from '../interfaces/decoded';
declare type MethodSigs = {
    [key: string]: ABI_Function;
};
declare type EventSigs = {
    [key: string]: {
        [key: string]: ABI_Event;
    };
};
export default class ABIDecoder {
    methodSigs: MethodSigs;
    eventSigs: EventSigs;
    eventSigOptions: EventSigOptions;
    abiRows: ABI_Row[];
    db: DatabaseInterface;
    constructor(databaseInterface: DatabaseInterface);
    addABI(abiMap: Record<string, ABI_Item[]>): void;
    getABIEventFromExternalSource(hexSignature: string): Promise<ABI_Event | undefined>;
    getABIFunctionFromExternalSource(hexSignature: string): Promise<ABI_Function | undefined>;
    decodeMethod(data: string): Promise<RawDecodedCallData>;
    decodeLogs(logs: Log[], contractDataMap: Record<string, ContractData>): Promise<RawDecodedLog[]>;
    removeABI(abiArray: ABI_Item[]): void;
}
export {};
