"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const FourByteDirectory_1 = __importDefault(require("./clients/FourByteDirectory"));
const logging_1 = require("./logging");
const ethers_1 = require("ethers");
const abi_1 = require("../interfaces/abi");
const utils_1 = require("../interfaces/utils");
const utils_2 = require("../utils");
const erc20_json_1 = __importDefault(require("../utils/ABIs/erc20.json"));
const erc721_json_1 = __importDefault(require("../utils/ABIs/erc721.json"));
const erc1155_json_1 = __importDefault(require("../utils/ABIs/erc1155.json"));
const web3_abi_coder_1 = __importDefault(require("../utils/web3-abi-coder"));
const transferHash = (0, utils_2.hash)('Transfer(address,address,uint256)');
const approvalHash = (0, utils_2.hash)('Approval(address,address,uint256)');
const transferSingleHashErc1155 = (0, utils_2.hash)('TransferSingle(address,address,address,uint256,uint256)');
const approvalForAllHash = (0, utils_2.hash)('ApprovalForAll(address,address,bool)');
function getABIForTransferEvent(contractType) {
    switch (contractType) {
        case "ERC20" /* ContractType.ERC20 */:
            return erc20_json_1.default.find((abi) => abi.name === 'Transfer');
        case "ERC721" /* ContractType.ERC721 */:
            return erc721_json_1.default.find((abi) => abi.name === 'Transfer');
        default:
            return null;
    }
}
function getABIForApprovalEvent(contractType) {
    switch (contractType) {
        case "ERC20" /* ContractType.ERC20 */:
            return erc20_json_1.default.find((abi) => abi.name === 'Approval');
        case "ERC721" /* ContractType.ERC721 */:
            return erc721_json_1.default.find((abi) => abi.name === 'Approval');
        default:
            return null;
    }
}
function getABIForApprovalForAllEvent(contractType) {
    return contractType === "ERC721" /* ContractType.ERC721 */
        ? erc721_json_1.default.find((abi) => abi.name === 'ApprovalForAll')
        : erc1155_json_1.default.find((abi) => abi.name === 'ApprovalForAll');
}
const abiCoder = new web3_abi_coder_1.default();
class ABIDecoder {
    constructor(databaseInterface) {
        this.methodSigs = {};
        this.eventSigs = {};
        this.eventSigOptions = {};
        this.abiRows = [];
        this.db = databaseInterface;
    }
    addABI(abiMap) {
        (0, utils_2.getEntries)(abiMap).map(([contractAddress, abiArray]) => {
            abiArray.map((abi) => {
                const abiRow = (0, utils_2.abiToAbiRow)(abi);
                this.abiRows.push(abiRow);
                if (abiRow.type === abi_1.ABI_Type.enum.event) {
                    // per contract ABIs so erc20 Transfer and erc721 Transfer don't conflict
                    this.eventSigs[contractAddress] = this.eventSigs[contractAddress] || {};
                    this.eventSigs[contractAddress][abiRow.hashedSignature] = abiRow.abiJSON;
                }
                else if (abiRow.type === abi_1.ABI_Type.enum.function) {
                    this.methodSigs[abiRow.hashedSignature] = abiRow.abiJSON;
                }
            });
        });
    }
    getABIEventFromExternalSource(hexSignature) {
        return __awaiter(this, void 0, void 0, function* () {
            const abiSig = yield FourByteDirectory_1.default.getEventSignature(hexSignature);
            console.log('abiSig', abiSig);
            return abiSig
                ? {
                    name: abiSig,
                    type: 'event',
                    inputs: [],
                    anonymous: false,
                }
                : undefined;
        });
    }
    getABIFunctionFromExternalSource(hexSignature) {
        return __awaiter(this, void 0, void 0, function* () {
            const contractMethod = yield FourByteDirectory_1.default.getMethodSignature(hexSignature);
            return contractMethod
                ? {
                    name: contractMethod,
                    type: 'function',
                    inputs: [],
                    outputs: [],
                    stateMutability: undefined,
                }
                : undefined;
        });
    }
    decodeMethod(data) {
        return __awaiter(this, void 0, void 0, function* () {
            const methodID = data.slice(0, 10);
            // TODO shouldn't just be grabbing index 0
            // const abiItem = this.methodSigs[methodID] || (await this.db.getABIsForHexSignature(methodID))?.[0]
            // const abiItem = this.methodSigs[methodID] || (await this.getABIFunctionFromExternalSource(methodID))
            // const abiItem = await this.getABIFunctionFromExternalSource(methodID)
            const abiResult = this.methodSigs[methodID];
            let abiItem = abiResult ? abi_1.ABI_FunctionZ.parse(abiResult) : null;
            let abiItemOptions = [];
            let decoded;
            // if we have a match, try decoding it. if it doesn't fit, or we don't have a match, get options from the db
            if (abiItem) {
                try {
                    decoded = abiCoder.decodeParameters(abiItem.inputs, data.slice(10));
                }
                catch (_a) {
                    abiItemOptions = yield this.db.getFunctionABIsForHexSignature(methodID);
                }
            }
            else {
                abiItemOptions = yield this.db.getFunctionABIsForHexSignature(methodID);
            }
            if (abiItemOptions.length > 0) {
                // try all of the options, it'll throw an error if it doesn't match, catch it, try the next one
                while ((!decoded || !Object.keys(decoded).length) && abiItemOptions.length > 0) {
                    abiItem = abiItemOptions.shift();
                    try {
                        decoded = abiCoder.decodeParameters(abiItem.inputs, data.slice(10));
                    }
                    catch (e) {
                        //try again
                    }
                }
            }
            const blankReturnData = {
                name: null,
                params: [],
            };
            const warningLogData = {
                function_name: 'decodeMethod',
                method_id: methodID,
                abi_item: abiItem,
            };
            if (abiItem && decoded) {
                try {
                    const returnData = {
                        name: abiItem.name,
                        params: [],
                    };
                    for (let i = 0; i < Object.keys(decoded).length; i++) {
                        // for (let i = 0; i < decoded.__length__; i++) {
                        const param = decoded[i];
                        let parsedParam = param;
                        const isUint = abiItem.inputs[i].type.indexOf('uint') === 0;
                        const isInt = abiItem.inputs[i].type.indexOf('int') === 0;
                        const isAddress = abiItem.inputs[i].type.indexOf('address') === 0;
                        if (isUint || isInt) {
                            const isArray = Array.isArray(param);
                            if (isArray) {
                                parsedParam = param.map((val) => ethers_1.BigNumber.from(val).toString());
                            }
                            else {
                                parsedParam = param ? ethers_1.BigNumber.from(param).toString() : null;
                            }
                        }
                        // Addresses returned by web3 are randomly cased so we need to standardize and lowercase all
                        if (isAddress) {
                            const isArray = Array.isArray(param);
                            if (isArray) {
                                parsedParam = param.map((_) => _.toLowerCase());
                            }
                            else {
                                parsedParam = param.toLowerCase();
                            }
                        }
                        returnData.params.push({
                            name: abiItem.inputs[i].name || '',
                            value: parsedParam,
                            type: abiItem.inputs[i].type,
                        });
                    }
                    return returnData;
                }
                catch (e) {
                    (0, logging_1.logWarning)(warningLogData, e.message);
                    return blankReturnData;
                }
            }
            else {
                return blankReturnData;
            }
        });
    }
    decodeLogs(logs, contractDataMap) {
        return __awaiter(this, void 0, void 0, function* () {
            const eventIDs = [...new Set(logs.map((log) => log.topics[0]))];
            this.eventSigOptions = yield this.db.getManyEventABIsForHexSignatures(eventIDs);
            return logs
                .filter((log) => log.topics.length > 0)
                .map((logItem) => {
                const eventID = logItem.topics[0];
                const address = utils_1.AddressZ.parse(logItem.address);
                // first check if it the contract's abi has it
                let abiItem = this.eventSigs[address] ? this.eventSigs[address][eventID] : null;
                let abiItemOptions = [];
                // hardcode known events that can be named differently by custom ABIs, but we use the default names for our generic Interpreters
                if (eventID === transferHash) {
                    abiItem = getABIForTransferEvent(contractDataMap[address].type) || abiItem;
                }
                if (eventID === transferSingleHashErc1155) {
                    abiItem = erc1155_json_1.default.find((abi) => abi.name === 'TransferSingle');
                }
                if (eventID === approvalHash) {
                    abiItem = getABIForApprovalEvent(contractDataMap[address].type) || abiItem;
                }
                if (eventID === approvalForAllHash) {
                    abiItem = getABIForApprovalForAllEvent(contractDataMap[address].type) || abiItem;
                }
                let decodedData = null;
                let dataIndex = 0;
                let topicsIndex = 1;
                const logData = logItem.data.slice(2);
                const topicsCount = logItem.topics.length - 1;
                let indexedCount = 0;
                function getDecodedData(logData, abiItem) {
                    const dataTypes = [];
                    abiItem.inputs.map(function (input) {
                        if (!input.indexed) {
                            dataTypes.push(input.type);
                        }
                    });
                    return abiCoder.decodeParameters(dataTypes, logData);
                }
                // if we found a match, try to decode. if it doesn't fit, or we don't have a match, get options from the db
                if (abiItem) {
                    try {
                        decodedData = getDecodedData(logData, abiItem);
                    }
                    catch (e) {
                        abiItemOptions = [...(this.eventSigOptions[eventID] || [])];
                    }
                }
                else {
                    abiItemOptions = [...(this.eventSigOptions[eventID] || [])];
                }
                if (abiItemOptions.length > 0) {
                    // try all of the options, it'll throw an error if it doesn't match, catch it, try the next one
                    while (!(decodedData || abiItemOptions.length === 0 || topicsCount == indexedCount)) {
                        abiItem = abiItemOptions.shift();
                        indexedCount = abiItem.inputs.filter((_) => _.indexed).length;
                        try {
                            decodedData = getDecodedData(logData, abiItem);
                        }
                        catch (e) {
                            //try again
                        }
                    }
                }
                const blankRawLog = {
                    name: null,
                    events: [],
                    address: logItem.address,
                    logIndex: logItem.logIndex,
                    decoded: false,
                };
                const warningLogData = {
                    function_name: 'decodeLogs',
                    address: logItem.address,
                    tx_hash: logItem.transactionHash,
                    log_item: logItem,
                    abi_item: abiItem,
                };
                if (abiItem && decodedData) {
                    try {
                        const decodedParams = [];
                        // Loop topic and data to get the params
                        abiItem.inputs.map(function (param) {
                            const decodedP = {
                                name: param.name || '',
                                type: param.type,
                                value: '',
                            };
                            if (param.indexed) {
                                decodedP.value = logItem.topics[topicsIndex];
                                topicsIndex++;
                            }
                            else {
                                decodedP.value = decodedData[dataIndex];
                                dataIndex++;
                            }
                            if (param.type === 'address' && typeof decodedP.value === 'string') {
                                decodedP.value = decodedP.value.toLowerCase();
                                // 42 because len(0x) + 40
                                if (decodedP.value.length > 42) {
                                    const toRemove = decodedP.value.length - 42;
                                    const temp = decodedP.value.split('');
                                    temp.splice(2, toRemove);
                                    decodedP.value = temp.join('');
                                }
                            }
                            if (param.type === 'uint256' || param.type === 'uint8' || param.type === 'int') {
                                if (typeof decodedP.value === 'string') {
                                    decodedP.value = ethers_1.BigNumber.from(decodedP.value).toString();
                                }
                                else {
                                    decodedP.value = decodedP.value.toString();
                                }
                            }
                            decodedParams.push(decodedP);
                        });
                        return {
                            events: decodedParams,
                            name: abiItem.name,
                            address: utils_1.AddressZ.parse(logItem.address),
                            logIndex: logItem.logIndex,
                            decoded: true,
                        };
                    }
                    catch (e) {
                        (0, logging_1.logWarning)(warningLogData, e.message);
                        return blankRawLog;
                    }
                }
                else {
                    return blankRawLog;
                }
            });
        });
    }
    removeABI(abiArray) {
        // Iterate new abi to generate method id"s
        abiArray.map((abi) => {
            if (abi.name) {
                const signature = (0, utils_2.hash)(abi.name +
                    '(' +
                    abi.inputs
                        .map(function (input) {
                        return input.type;
                    })
                        .join(',') +
                    ')');
                if (abi.type === 'event') {
                    if (this.methodSigs[signature]) {
                        delete this.methodSigs[signature];
                    }
                }
                else {
                    if (this.methodSigs[signature.slice(0, 10)]) {
                        delete this.methodSigs[signature.slice(0, 10)];
                    }
                }
            }
        });
    }
}
exports.default = ABIDecoder;
//# sourceMappingURL=abi-decoder.js.map