"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ethers_1 = require("ethers");
const constants_1 = require("../utils/constants");
function checkInterface(contractAddress, provider) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const contract = new ethers_1.Contract(contractAddress, supportsInterfaceABI, provider);
            if (yield contract.supportsInterface(constants_1.ERC721InterfaceId)) {
                return "ERC721" /* ContractType.ERC721 */;
            }
            else if (yield contract.supportsInterface(constants_1.ERC1155InterfaceId)) {
                return "ERC1155" /* ContractType.ERC1155 */;
            }
            else if (yield contract.supportsInterface(constants_1.ERC20InterfaceId)) {
                return "ERC20" /* ContractType.ERC20 */;
            }
            else {
                return "OTHER" /* ContractType.OTHER */;
            }
        }
        catch (e) {
            // console.log(`${contractAddress} doesn't have a supportsInterface function`)
            return "OTHER" /* ContractType.OTHER */;
        }
    });
}
exports.default = checkInterface;
const supportsInterfaceABI = [
    {
        inputs: [
            {
                internalType: 'bytes4',
                name: 'interfaceId',
                type: 'bytes4',
            },
        ],
        name: 'supportsInterface',
        outputs: [
            {
                internalType: 'bool',
                name: '',
                type: 'bool',
            },
        ],
        stateMutability: 'view',
        type: 'function',
    },
];
//# sourceMappingURL=checkInterface.js.map