"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
class Covalent {
    constructor(covalentApiKey, chainId = 1) {
        this.client = axios_1.default.create({
            baseURL: 'https://api.covalenthq.com/v1/',
            auth: {
                username: covalentApiKey,
                password: '',
            },
        });
        this.chainId = chainId; // default to 1 for ethereum
    }
    getBalancesFor(address, { page, limit } = {}) {
        return this.client
            .get(`${this.chainId}/address/${address}/balances_v2/`, {
            params: {
                'page-size': limit !== null && limit !== void 0 ? limit : 100,
                'page-number': page !== null && page !== void 0 ? page : 0,
            },
        })
            .then((res) => res.data.data);
    }
    // TODO pagination loop logic should live in here, with a txn count limit optional param
    getTransactionsFor(address, limit) {
        return this.client
            .get(`${this.chainId}/address/${address}/transactions_v2/`, {
            params: {
                'page-size': limit !== null && limit !== void 0 ? limit : 999999,
                'page-number': 0,
                'no-logs': true,
            },
        })
            .then((res) => {
            if (res.data.data.pagination.has_more) {
                console.log('Theres more transactions to fetch from Covalent!');
            }
            return res.data.data.items;
        });
    }
    getTransactionFor(txHash) {
        return this.client.get(`${this.chainId}/transaction_v2/${txHash}/`).then((res) => res.data.data);
    }
}
exports.default = Covalent;
//# sourceMappingURL=Covalent.js.map