"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const abi_1 = require("../../interfaces/abi");
const utils_1 = require("../../utils");
const logging_1 = require("../../utils/logging");
class Etherscan {
    constructor(apiKey, etherscanServiceLevel = 5 /* EtherscanServiceLevel.free */) {
        this.baseUrl = 'https://api.etherscan.io/api';
        this.apiKey = apiKey;
        this.fetcher = new utils_1.Fetcher(etherscanServiceLevel);
    }
    createUrl(params) {
        const url = new URL(this.baseUrl);
        url.searchParams.set('apikey', this.apiKey);
        Object.entries(params).forEach(([key, value]) => {
            url.searchParams.set(key, value);
        });
        return url.toString();
    }
    static abiParams(contractAddress) {
        return {
            module: 'contract',
            action: 'getabi',
            address: contractAddress,
        };
    }
    static parseABIResponse(response, address = null) {
        if (response.result == 'Contract source code not verified') {
            return [];
        }
        const logData = {
            address: address !== null && address !== void 0 ? address : '',
            function_name: 'parseABIResponse',
            extra: response,
        };
        if (response.status !== '1') {
            (0, logging_1.logError)(logData, { message: response.result });
            // console.warn(`Etherscan API error: ${response.result}`)
            // throw new Error(`Etherscan API error: ${response.result}`)
            return [];
        }
        const abiArray = JSON.parse(response.result);
        console.log('abiArray logan:', abiArray);
        const abiArrayValidated = abiArray
            .map((fragment) => {
            const parsed = abi_1.ABI_ItemUnfilteredZ.safeParse(fragment);
            return parsed.success ? parsed.data : null;
        })
            .filter((x) => x !== null);
        return abiArrayValidated;
    }
    getABI(contractAddress) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.fetcher.fetch(this.createUrl(Etherscan.abiParams(contractAddress)));
            return Etherscan.parseABIResponse(response, contractAddress);
        });
    }
    getABIs(contractAddresses) {
        return __awaiter(this, void 0, void 0, function* () {
            const ABIMap = {};
            const errors = [];
            const abiPromises = contractAddresses.map((contractAddress) => {
                return this.fetcher.fetch(this.createUrl(Etherscan.abiParams(contractAddress)));
            });
            const abiResults = yield (0, utils_1.promiseAll)(abiPromises, errors);
            const abis = abiResults.map((abiResult, i) => Etherscan.parseABIResponse(abiResult, contractAddresses[i]));
            abis.forEach((abi, i) => {
                ABIMap[contractAddresses[i]] = abi;
            });
            if (errors.length > 0) {
                console.warn('errors:', errors);
            }
            return ABIMap;
        });
    }
    getSourceCode(contractAddress) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = {
                module: 'contract',
                action: 'getsourcecode',
                address: contractAddress,
            };
            const response = yield this.fetcher.fetch(this.createUrl(params));
            if (response.status !== '1') {
                throw new Error(`Etherscan API error bad status: ${response.result}`);
            }
            if (response.result[0].ABI === 'Contract source code not verified') {
                throw new Error(`Etherscan API error not verified: ${response.result.ABI}`);
            }
            return response.result[0];
        });
    }
}
exports.default = Etherscan;
//# sourceMappingURL=Etherscan.js.map