"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Etherscan_1 = __importDefault(require("./clients/Etherscan"));
const abi_1 = require("../interfaces/abi");
const utils_1 = require("../utils");
class InterpreterTemplateGenerator {
    constructor(etherscanApiKey) {
        this.etherscan = new Etherscan_1.default(etherscanApiKey);
    }
    generateInterpreter(contractAddress) {
        return __awaiter(this, void 0, void 0, function* () {
            let sourceCode;
            try {
                sourceCode = yield this.etherscan.getSourceCode(contractAddress);
            }
            catch (e) {
                console.error(e);
                throw new Error(`Etherscan API error: ${e.message}`);
            }
            const abiUnfiltered = JSON.parse(sourceCode.ABI);
            console.log('contract name', sourceCode.ContractName);
            const contractOfficialName = sourceCode.ContractName;
            const ABIs = abiUnfiltered.filter(({ type }) => type === 'function' || type === 'event');
            const abiRows = ABIs.map((abi) => (0, utils_1.abiToAbiRow)(abi));
            const writeFunctions = abiRows.filter((abiRow) => abiRow.type === abi_1.ABI_Type.enum.function &&
                (abi_1.writeStates.includes(abiRow.abiJSON.stateMutability || '') ||
                    !abi_1.readStates.includes(abiRow.abiJSON.stateMutability || '')));
            const interpreterMap = {
                contractAddress,
                contractOfficialName,
                contractName: '______TODO______',
                entityName: '______TODO______',
                writeFunctions: {},
            };
            writeFunctions.forEach((abi) => {
                interpreterMap.writeFunctions[abi.name] = {
                    action: "______TODO______" /* Action.______TODO______ */,
                    exampleDescriptionTemplate: '______TODO______',
                    exampleDescription: '______TODO______',
                    keywords: {
                        __EXAMPLE_KEYWORD__: {
                            key: '______TODO______',
                            filters: {},
                            defaultValue: '______TODO______',
                        },
                    },
                };
            });
            return interpreterMap;
        });
    }
}
exports.default = InterpreterTemplateGenerator;
//# sourceMappingURL=generateInterpreter.js.map