"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const collect_js_1 = __importDefault(require("collect.js"));
function getTypeFromABI(contractAddress, etherscan, abiArr = null) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const unfilteredAbi = abiArr || (yield etherscan.getABI(contractAddress));
            const abi = unfilteredAbi.filter(({ type }) => type === 'function' || type === 'event');
            const names = (0, collect_js_1.default)(abi.map(({ name }) => name));
            const ERC1155Only = ['TransferBatch', 'TransferSingle', 'URI', 'balanceOfBatch', 'safeBatchTransferFrom'];
            const ERC1155Not = ['Approval', 'Transfer', 'approve', 'transferFrom'];
            const ERC20Only = ['allowance', 'totalSupply', 'transfer'];
            const ERC20Not = ['ApprovalForAll', 'isApprovedForAll', 'safeTransferFrom', 'setApprovalForAll'];
            const ERC721Only = ['getApproved'];
            const ERC721Not = [];
            const isERC1155 = names.intersect(ERC1155Only).isNotEmpty() && names.intersect(ERC1155Not).isEmpty();
            const isERC20 = names.intersect(ERC20Only).isNotEmpty() && names.intersect(ERC20Not).isEmpty();
            const isERC721 = names.intersect(ERC721Only).isNotEmpty() && names.intersect(ERC721Not).isEmpty();
            if ((isERC20 && isERC721) || (isERC20 && isERC1155) || (isERC721 && isERC1155)) {
                throw new Error(`Contract ${contractAddress} fits multiple ERC specs, this must be malicious?`);
            }
            if (isERC1155) {
                return "ERC1155" /* ContractType.ERC1155 */;
            }
            if (isERC20) {
                return "ERC20" /* ContractType.ERC20 */;
            }
            if (isERC721) {
                return "ERC721" /* ContractType.ERC721 */;
            }
            return "OTHER" /* ContractType.OTHER */;
        }
        catch (e) {
            console.log('getTypeFromABI', e);
            return "OTHER" /* ContractType.OTHER */;
        }
    });
}
exports.default = getTypeFromABI;
//# sourceMappingURL=getTypeFromABI.js.map