import { BaseProvider } from '@ethersproject/providers';
import Bottleneck from 'bottleneck';
import { Response } from 'node-fetch';
import { ABI_Item, ABI_ItemUnfiltered, ABI_Row } from '../interfaces/abi';
import { Interaction, InteractionEvent } from '../interfaces/decoded';
import { Interpretation } from '../interfaces/interpreted';
import { Chain, Chains } from '../interfaces/utils';
export declare const chains: Chains;
export declare const getChainById: (id: number) => Chain;
export declare const getChainBySymbol: (symbol: string) => Chain;
export declare const getStablecoinOrNativeWrappedAddressesBySymbol: (symbol: string) => string[];
export declare const getDecimals: (contractAddress: string, chain?: Chain) => number;
export declare const isAddress: (address: string) => boolean;
export declare const cleanseDataInPlace: (data: any) => void;
export declare class FetcherError extends Error {
    status: any;
    statusText: any;
    url: any;
    bodySent: any;
    constructor({ message, status, statusText, url, bodySent, }: {
        message: string;
        status: any;
        statusText: any;
        url: any;
        bodySent: any;
    });
    toJSON(): {
        name: string;
        status: any;
        statusText: any;
        url: any;
        bodySent: any;
        message: string;
    };
}
export declare function sleep(ms: number): Promise<unknown>;
export declare class Fetcher {
    limiter: Bottleneck;
    fetchDefaultOptions: {
        body: undefined;
    };
    constructor(perSecond?: number);
    scheduleRequest(url: string, options?: Record<string, any>): Promise<Response>;
    fetch(url: string, options?: Record<string, any>): Promise<any>;
}
export declare function fetcher(url: string, options?: {
    body: undefined;
}): Promise<any>;
export declare const retryProviderCall: <T>(providerPromise: Promise<T>) => Promise<Awaited<T>>;
export declare function fillDescriptionTemplate(template: string, interpretation: Interpretation): string;
export declare const shortenName: (username: string) => string;
export declare const shortenNamesInString: (string: string) => string;
export declare const getNativeTokenValueEvents: (interactions: Interaction[]) => InteractionEvent[];
export declare const getKeys: <T>(obj: T) => (keyof T)[];
export declare const getEntries: <T>(obj: Record<string, T>) => [string, T][];
export declare const getValues: <T>(obj: Record<string, T>) => T[];
export declare function filterABI(unfilteredABI: ABI_ItemUnfiltered[]): ABI_Item[];
export declare function filterABIMap(unfilteredABIs: Record<string, ABI_ItemUnfiltered[]>): Record<string, ABI_Item[]>;
export declare function filterABIArray(unfilteredABIs: ABI_ItemUnfiltered[]): ABI_Item[];
export declare function hash(data: string): string;
export declare function abiToAbiRow(abi: ABI_Item): ABI_Row;
export declare function abiArrToAbiRows(abiArr: ABI_Item[]): ABI_Row[];
export declare function promiseAll(promises: Array<Promise<any>>, errors: any[]): Promise<any[]>;
export declare function getProxyAddresses(provider: BaseProvider, addresses: string[]): Promise<Array<string | null>>;
export declare function toOrFromUser(event: InteractionEvent, direction: 'to' | 'from', userAddress: string): boolean;
export declare function checkMultipleKeys(interactionEvent: InteractionEvent, key: string, valueToFind?: string | null): any;
export declare function flattenEventsFromInteractions(filteredInteractions: Interaction[]): InteractionEvent[];
