"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.flattenEventsFromInteractions = exports.checkMultipleKeys = exports.toOrFromUser = exports.getProxyAddresses = exports.promiseAll = exports.abiArrToAbiRows = exports.abiToAbiRow = exports.hash = exports.filterABIArray = exports.filterABIMap = exports.filterABI = exports.getValues = exports.getEntries = exports.getKeys = exports.getNativeTokenValueEvents = exports.shortenNamesInString = exports.shortenName = exports.fillDescriptionTemplate = exports.retryProviderCall = exports.fetcher = exports.Fetcher = exports.sleep = exports.FetcherError = exports.cleanseDataInPlace = exports.isAddress = exports.getDecimals = exports.getStablecoinOrNativeWrappedAddressesBySymbol = exports.getChainBySymbol = exports.getChainById = exports.chains = void 0;
const constants_1 = require("./constants");
const logging_1 = require("./logging");
const alchemy_sdk_1 = require("@alch/alchemy-sdk");
const bottleneck_1 = __importDefault(require("bottleneck"));
const collect_js_1 = __importDefault(require("collect.js"));
const ethers_1 = require("ethers");
const utils_1 = require("ethers/lib/utils");
const node_fetch_1 = __importDefault(require("node-fetch"));
const traverse_1 = __importDefault(require("traverse"));
const abi_1 = require("../interfaces/abi");
const utils_2 = require("../interfaces/utils");
const DoubleSidedTxInterpreter_1 = require("../core/DoubleSidedTxInterpreter");
// Despite most contracts using Open Zeppelin's standard naming convention of "to, from, value", not all do. Most notably, DAI and WETH use "src, dst, wad". These are used rename the keys to match the standard (both for generic and contract-specific interpretations).
const toKeys = ['to', '_to', 'dst'];
const fromKeys = ['from', '_from', 'src'];
const valueKeys = ['value', 'wad', 'amount'];
const toKey = 'to';
const fromKey = 'from';
const valueKey = 'value';
const ethereum = {
    EVM: true,
    id: 1,
    name: 'Ethereum',
    symbol: "ETH" /* ChainSymbol.ETH */,
    testnet: false,
    blockExplorerUrl: 'https://etherscan.io/',
    wethAddress: '0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2',
    usdcAddress: '0xa0b86991c6218b36c1d19d4a2e9eb0ce3606eb48',
    usdtAddress: '0xdac17f958d2ee523a2206206994597c13d831ec7',
    daiAddress: '0x6b175474e89094c44da98b954eedeac495271d0f',
    nativeAssetAddress: constants_1.ethAddress,
    alchemyNetworkString: alchemy_sdk_1.Network.ETH_MAINNET,
};
const polygon = {
    EVM: true,
    id: 137,
    name: 'Polygon',
    symbol: "MATIC" /* ChainSymbol.MATIC */,
    testnet: false,
    blockExplorerUrl: 'https://polygonscan.com/',
    wethAddress: '0x7ceb23fd6bc0add59e62ac25578270cff1b9f619',
    usdcAddress: '0x2791bca1f2de4661ed88a30c99a7a9449aa84174',
    usdtAddress: '0xc2132d05d31c914a87c6611c10748aeb04b58e8f',
    daiAddress: '0x8f3cf7ad23cd3cadbd9735aff958023239c6a063',
    nativeAssetAddress: constants_1.ethAddress,
    alchemyNetworkString: alchemy_sdk_1.Network.MATIC_MAINNET,
};
exports.chains = {
    ethereum,
    polygon,
};
const getChainById = (id) => {
    const chain = (0, collect_js_1.default)(exports.chains).first((chain) => chain.id === id);
    if (!chain) {
        throw new Error(`Chain with id ${id} not found`);
    }
    return chain;
};
exports.getChainById = getChainById;
const getChainBySymbol = (symbol) => {
    const chain = (0, collect_js_1.default)(exports.chains).first((chain) => chain.symbol === symbol);
    if (!chain) {
        throw new Error(`Chain with symbol ${symbol} not found`);
    }
    return chain;
};
exports.getChainBySymbol = getChainBySymbol;
const getStablecoinOrNativeWrappedAddressesBySymbol = (symbol) => {
    const chain = (0, exports.getChainBySymbol)(symbol);
    return [chain.wethAddress, chain.usdcAddress, chain.usdtAddress, chain.daiAddress, chain.nativeAssetAddress];
};
exports.getStablecoinOrNativeWrappedAddressesBySymbol = getStablecoinOrNativeWrappedAddressesBySymbol;
// TODO hardcoded but should be a call to a db that checks the contractAddress's decimal()
const getDecimals = (contractAddress, chain = exports.chains.ethereum) => {
    if (!contractAddress)
        return 18;
    const address = contractAddress.toLowerCase();
    const hexAddress = '0x2b591e99afe9f32eaa6214f7b7629768c40eeb39'; // hack
    const wBTCAddress = '0x2260fac5e5542a773aa44fbcfedf7c193bc2c599';
    if ([chain.usdcAddress, chain.usdtAddress, hexAddress].includes(address)) {
        return 6;
    }
    else if (address === wBTCAddress) {
        return 8;
    }
    else {
        return 18;
    }
};
exports.getDecimals = getDecimals;
const isAddress = (address) => {
    const validAddress = new RegExp(/^0x[a-fA-F0-9]{40}$/);
    return validAddress.test(address);
};
exports.isAddress = isAddress;
const cleanseDataInPlace = (data) => {
    (0, traverse_1.default)(data).forEach(function (x) {
        if (x instanceof ethers_1.BigNumber) {
            this.update(x.toString());
        }
        if (typeof x === 'undefined') {
            this.update(null);
        }
    });
};
exports.cleanseDataInPlace = cleanseDataInPlace;
const fetchOptions = {
    body: undefined,
};
class FetcherError extends Error {
    constructor({ message, status, statusText, url, bodySent, }) {
        super(message);
        this.name = 'Fetcher Error';
        this.status = status;
        this.statusText = statusText;
        this.url = url;
        this.bodySent = bodySent;
    }
    toJSON() {
        return {
            name: this.name,
            status: this.status,
            statusText: this.statusText,
            url: this.url,
            bodySent: this.bodySent,
            message: this.message,
        };
    }
}
exports.FetcherError = FetcherError;
function sleep(ms) {
    return new Promise((resolve) => setTimeout(resolve, ms));
}
exports.sleep = sleep;
class Fetcher {
    constructor(perSecond = 100) {
        this.fetchDefaultOptions = {
            body: undefined,
        };
        const maxConcurrent = perSecond;
        const minTime = (1000 / perSecond) * 1.3;
        this.limiter = new bottleneck_1.default({ maxConcurrent, minTime });
    }
    scheduleRequest(url, options = this.fetchDefaultOptions) {
        return this.limiter.schedule(() => (0, node_fetch_1.default)(url, options));
    }
    fetch(url, options = fetchOptions) {
        return __awaiter(this, void 0, void 0, function* () {
            let retry = 3;
            while (retry > 0) {
                const response = yield this.scheduleRequest(url, options);
                if (response.ok) {
                    return response.json();
                }
                else {
                    const error = {
                        status: response.status,
                        statusText: response.statusText,
                        url: response.url,
                        bodySent: options.body ? JSON.parse(options.body) : null,
                        message: yield response.text(),
                    };
                    retry--;
                    if (retry === 0) {
                        throw new FetcherError(error);
                    }
                    yield sleep(2000);
                }
            }
        });
    }
}
exports.Fetcher = Fetcher;
function fetcher(url, options = fetchOptions) {
    return __awaiter(this, void 0, void 0, function* () {
        let retry = 3;
        while (retry > 0) {
            const response = yield (0, node_fetch_1.default)(url, options);
            if (response.ok) {
                return response.json();
            }
            else {
                const error = {
                    status: response.status,
                    statusText: response.statusText,
                    url: response.url,
                    bodySent: options.body ? JSON.parse(options.body) : null,
                    message: yield response.text(),
                };
                retry--;
                if (retry === 0) {
                    throw new FetcherError(error);
                }
                yield sleep(2000);
            }
        }
    });
}
exports.fetcher = fetcher;
const retryProviderCall = (providerPromise) => __awaiter(void 0, void 0, void 0, function* () {
    let retry = 4;
    const waitTimes = [0, 8000, 4000, 2000];
    let error = null;
    while (retry > 0) {
        try {
            const data = yield providerPromise;
            return data;
        }
        catch (err) {
            retry--;
            (0, logging_1.logWarning)({ thrown_error: err }, `retries left: ${retry}`);
            if (retry === 0) {
                error = err;
            }
            else {
                yield sleep(waitTimes[retry]);
            }
        }
    }
    throw error;
});
exports.retryProviderCall = retryProviderCall;
function fillDescriptionTemplate(template, interpretation) {
    const merged = (0, collect_js_1.default)(interpretation.extra).merge(interpretation).all();
    // If transaction is 2-sided, we need to get sale price from either nativeValueSent or nativeValueReceived
    if (template.includes('__NATIVEVALUETRANSFERRED__')) {
        merged.__NATIVEVALUETRANSFERRED__ = (0, DoubleSidedTxInterpreter_1.getNativeValueTransferredForDoubleSidedTx)(interpretation);
    }
    // Handle actions being an array --> simplify to a single action
    if (merged.actions.length > 1) {
        merged.action = "executed multiple actions" /* Action.multicall */;
    }
    else if (merged.actions.length) {
        merged.action = merged.actions[0];
    }
    else {
        merged.action = "unknown" /* Action.unknown */;
    }
    for (const [key, value] of Object.entries(merged)) {
        if (typeof value === 'string') {
            template = template.replace(`{${key}}`, value);
        }
    }
    return template;
}
exports.fillDescriptionTemplate = fillDescriptionTemplate;
const validAddress = new RegExp(/^0x[a-fA-F0-9]{40}$/);
const shortenName = (username) => {
    return validAddress.test(username) ? username.slice(0, 6) : username;
};
exports.shortenName = shortenName;
const shortenNamesInString = (string) => {
    return string.replace(/0x[a-fA-F0-9]{40}/g, (username) => {
        return (0, exports.shortenName)(username);
    });
};
exports.shortenNamesInString = shortenNamesInString;
const getNativeTokenValueEvents = (interactions) => {
    const nativeTokenEvents = [];
    for (const interaction of interactions) {
        for (const event of interaction.events) {
            if (event.nativeTransfer) {
                nativeTokenEvents.push(event);
            }
        }
    }
    return nativeTokenEvents;
};
exports.getNativeTokenValueEvents = getNativeTokenValueEvents;
const getKeys = (obj) => Object.keys(obj);
exports.getKeys = getKeys;
const getEntries = (obj) => Object.entries(obj);
exports.getEntries = getEntries;
const getValues = (obj) => Object.values(obj);
exports.getValues = getValues;
function filterABI(unfilteredABI) {
    return unfilteredABI.filter(({ type }) => type === 'function' || type === 'event');
}
exports.filterABI = filterABI;
function filterABIMap(unfilteredABIs) {
    const filteredABIs = {};
    for (const [address, unfilteredABI] of Object.entries(unfilteredABIs)) {
        const abi = filterABI(unfilteredABI);
        filteredABIs[address] = abi;
    }
    return filteredABIs;
}
exports.filterABIMap = filterABIMap;
function filterABIArray(unfilteredABIs) {
    return unfilteredABIs.filter(({ type }) => type === abi_1.ABI_Type.enum.event || type === abi_1.ABI_Type.enum.function);
}
exports.filterABIArray = filterABIArray;
function hash(data) {
    return (0, utils_1.keccak256)((0, utils_1.toUtf8Bytes)(data));
}
exports.hash = hash;
function abiToAbiRow(abi) {
    const frag = utils_1.Fragment.from(abi);
    if (!frag) {
        console.log('No frag!', abi);
    }
    const hashed = hash(frag.format(utils_1.FormatTypes.sighash));
    const signature = abi.type === abi_1.ABI_Type.enum.event ? hashed : hashed.slice(0, 10);
    const abiRow = abi_1.ABI_RowZ.parse({
        name: 'name' in abi ? abi.name : '',
        type: abi.type,
        hashableSignature: frag.format(utils_1.FormatTypes.sighash),
        hashedSignature: signature,
        fullSignature: frag.format(utils_1.FormatTypes.full),
        abiJSON: JSON.parse(frag.format(utils_1.FormatTypes.json)),
    });
    return abiRow;
}
exports.abiToAbiRow = abiToAbiRow;
function abiArrToAbiRows(abiArr) {
    return abiArr.map(abiToAbiRow);
}
exports.abiArrToAbiRows = abiArrToAbiRows;
function promiseAll(promises, errors) {
    return Promise.all(promises.map((p) => {
        return p.catch((e) => {
            errors.push(e);
            return e;
        });
    }));
}
exports.promiseAll = promiseAll;
function getProxyAddresses(provider, addresses) {
    return __awaiter(this, void 0, void 0, function* () {
        const proxyAddresses = yield Promise.all(addresses.map((address) => {
            console.log('getProxyAddress', address);
            return provider.getStorageAt(address, constants_1.proxyImplementationAddress).catch(() => null);
        }));
        return proxyAddresses.map((proxyAddress) => {
            try {
                return utils_2.AddressZ.parse(proxyAddress);
            }
            catch (e) {
                return null;
            }
        });
    });
}
exports.getProxyAddresses = getProxyAddresses;
function toOrFromUser(event, direction, userAddress) {
    const directionArr = direction === 'to' ? toKeys : fromKeys;
    return directionArr.filter((key) => event.params[key] === userAddress).length > 0;
}
exports.toOrFromUser = toOrFromUser;
// for example, DAI's Transfer event uses "dst" instead of "to", so we need to check for "dst" as well, even if the interpreter map uses "to". As we find more of these, we'll have to add them to the "toKeys" array. We mig
function checkMultipleKeys(interactionEvent, key, valueToFind = null) {
    if (!interactionEvent) {
        return valueToFind ? false : '';
    }
    const keyMapping = {
        [toKey]: toKeys,
        [fromKey]: fromKeys,
        [valueKey]: valueKeys,
    };
    const keys = keyMapping[key];
    if (keys) {
        for (const keyToCheck of keys) {
            if (valueToFind && interactionEvent.params[keyToCheck] === valueToFind) {
                return true;
            }
            else if (!valueToFind && interactionEvent.params[keyToCheck]) {
                return interactionEvent.params[keyToCheck];
            }
        }
    }
    return valueToFind ? false : '';
}
exports.checkMultipleKeys = checkMultipleKeys;
function flattenEventsFromInteractions(filteredInteractions) {
    return filteredInteractions.reduce((prev, cur) => {
        return [...prev, ...cur.events];
    }, []);
}
exports.flattenEventsFromInteractions = flattenEventsFromInteractions;
//# sourceMappingURL=index.js.map