import { Document, Types } from 'mongoose';
import { ABI_Event, ABI_Function, ABI_ItemUnfiltered, ABI_Row, EventSigOptions } from '../../interfaces/abi';
import { AddressNameData, ContractData, DecodedTx } from '../../interfaces/decoded';
import { DatabaseInterface } from '../../utils/DatabaseInterface';
export declare class MongooseDatabaseInterface extends DatabaseInterface {
    connectionString: string;
    constructor(connectionString: string);
    connect(): Promise<void>;
    getManyContractDataMap(contractAddresses: string[]): Promise<Record<string, ContractData | null>>;
    addOrUpdateManyContractData(contractDataArr: ContractData[]): Promise<void>;
    addOrUpdateManyABI(abiArr: ABI_Row[]): Promise<boolean>;
    getABIsForHexSignature(hexSignature: string): Promise<ABI_ItemUnfiltered[]>;
    getFirstABIForHexSignature(hexSignature: string): Promise<ABI_ItemUnfiltered | null>;
    getEventABIsForHexSignature(hexSignature: string): Promise<ABI_Event[]>;
    getManyEventABIsForHexSignatures(hexSignatures: string[]): Promise<EventSigOptions>;
    getFunctionABIsForHexSignature(hexSignature: string): Promise<ABI_Function[]>;
    addOrUpdateManyDecodedTx(decodedTxArr: DecodedTx[]): Promise<void>;
    deleteManyDecodedTxs(txHashes: string[]): Promise<number>;
    getManyDecodedTxMap(txHashes: string[]): Promise<Record<string, DecodedTx | null>>;
    getContractsBatch(lastId: string, batchSize: number): Promise<(Document<unknown, any, ContractData> & ContractData & {
        _id: Types.ObjectId;
    })[]>;
    closeConnection(): Promise<void>;
    getManyNameDataMap(addresses: string[]): Promise<Record<string, AddressNameData | null>>;
    getManyEntityMap(addresses: string[]): Promise<Record<string, string | null>>;
    getEntityByAddress(address: string): Promise<string | null>;
}
