"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MongooseDatabaseInterface = void 0;
const addressName_1 = require("./models/addressName");
const contract_1 = require("./models/contract");
const decodedTx_1 = require("./models/decodedTx");
const collect_js_1 = __importDefault(require("collect.js"));
const mongoose_1 = require("mongoose");
const abi_1 = require("../../interfaces/abi");
const utils_1 = require("../../utils");
const DatabaseInterface_1 = require("../../utils/DatabaseInterface");
const logging_1 = require("../../utils/logging");
const abi_2 = require("../../utils/mongoose/models/abi");
class MongooseDatabaseInterface extends DatabaseInterface_1.DatabaseInterface {
    constructor(connectionString) {
        super();
        this.connectionString = connectionString;
    }
    connect() {
        return __awaiter(this, void 0, void 0, function* () {
            // TODO
            // mongoose.connect('mongodb://user:pass@localhost:port/database', { autoIndex: false }); for PROD
            yield (0, mongoose_1.connect)(this.connectionString);
        });
    }
    getManyContractDataMap(contractAddresses) {
        return __awaiter(this, void 0, void 0, function* () {
            const contractMap = {};
            for (let i = 0; i < contractAddresses.length; i++) {
                contractMap[contractAddresses[i]] = null;
            }
            try {
                const modelData = yield contract_1.ContractModel.find({ address: { $in: contractAddresses } });
                const data = modelData.map((model) => model.toObject());
                for (let i = 0; i < contractAddresses.length; i++) {
                    const contractAddress = contractAddresses[i];
                    const contractData = data.find((contract) => contract.address === contractAddress);
                    contractMap[contractAddress] = contractData || null;
                }
            }
            catch (e) {
                console.log('get contract mongoose error');
                console.log(e);
                // return null
            }
            // return here instead of in the try, so that it still works if the db is down
            return contractMap;
        });
    }
    addOrUpdateManyContractData(contractDataArr) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            try {
                // only way to do bulk upsert
                yield contract_1.ContractModel.bulkWrite(contractDataArr.map((contract) => ({
                    updateOne: {
                        filter: { address: contract.address },
                        update: contract,
                        upsert: true,
                    },
                })));
            }
            catch (e) {
                if (!((_a = e === null || e === void 0 ? void 0 : e.message) === null || _a === void 0 ? void 0 : _a.includes('user is not allowed to do action [update]'))) {
                    console.log('contract mongoose error');
                    console.log(e);
                }
            }
        });
    }
    addOrUpdateManyABI(abiArr) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            // prob don'`t need these 3 lines but might it optimize the writes
            const uniqueABIsAsStrings = new Set();
            abiArr.map((abi) => uniqueABIsAsStrings.add(JSON.stringify(abi)));
            const uniqueABIs = Array.from(uniqueABIsAsStrings).map((str) => JSON.parse(str));
            try {
                // only way to do bulk upsert
                const { result } = yield abi_2.ABI_RowModel.bulkWrite(uniqueABIs.map((abi) => ({
                    updateOne: {
                        filter: { hashedSignature: abi.hashedSignature, fullSignature: abi.fullSignature },
                        update: abi,
                        upsert: true,
                    },
                })));
                if (result.nUpserted > 0) {
                    (0, logging_1.logInfo)({}, `Added ${result.nUpserted} ABIs`);
                }
                return true;
            }
            catch (e) {
                if (!((_a = e === null || e === void 0 ? void 0 : e.message) === null || _a === void 0 ? void 0 : _a.includes('user is not allowed to do action [update]'))) {
                    console.log('abi mongoose error');
                    console.log(e);
                }
                return false;
                // throw e
            }
        });
    }
    getABIsForHexSignature(hexSignature) {
        return __awaiter(this, void 0, void 0, function* () {
            const abiModels = yield abi_2.ABI_RowModel.find({ hashedSignature: hexSignature });
            const abis = abiModels.map((abi) => abi_1.ABI_RowZ.parse(abi.toObject()));
            return abis.map((abi) => abi.abiJSON);
        });
    }
    getFirstABIForHexSignature(hexSignature) {
        return __awaiter(this, void 0, void 0, function* () {
            const abis = (yield this.getABIsForHexSignature(hexSignature)) || [];
            return abis.length ? abis[0] : null;
        });
    }
    getEventABIsForHexSignature(hexSignature) {
        return __awaiter(this, void 0, void 0, function* () {
            const abiModels = yield abi_2.ABI_RowModel.find({ hashedSignature: hexSignature });
            const abisRows = abiModels.map((abi) => abi_1.ABI_RowZ.parse(abi.toObject()));
            abisRows.sort((a, b) => Number(b.default || false) - Number(a.default || false)); // get default(s) first
            const abis = abisRows.map((abi) => abi.abiJSON);
            const events = abis.filter((abi) => abi.type === abi_1.ABI_Type.enum.event);
            return events.map((event) => abi_1.ABI_EventZ.parse(event));
        });
    }
    getManyEventABIsForHexSignatures(hexSignatures) {
        return __awaiter(this, void 0, void 0, function* () {
            const abiModels = yield abi_2.ABI_RowModel.find({ hashedSignature: { $in: hexSignatures } });
            const abisRows = abiModels.map((abi) => abi_1.ABI_RowZ.parse(abi.toObject()));
            abisRows.sort((a, b) => Number(b.default || false) - Number(a.default || false)); // get default(s) first
            const events = abisRows.filter((row) => row.type === abi_1.ABI_Type.enum.event);
            const eventSigMap = (0, collect_js_1.default)(events)
                .mapToDictionary((row) => [row.hashedSignature, row.abiJSON])
                .all();
            return eventSigMap;
        });
    }
    getFunctionABIsForHexSignature(hexSignature) {
        return __awaiter(this, void 0, void 0, function* () {
            const abiModels = yield abi_2.ABI_RowModel.find({ hashedSignature: hexSignature });
            const abisRows = abiModels.map((abi) => abi_1.ABI_RowZ.parse(abi.toObject()));
            abisRows.sort((a, b) => Number(b.default || false) - Number(a.default || false)); // get default(s) first
            const abis = abisRows.map((abi) => abi.abiJSON);
            const events = abis.filter((abi) => abi.type === abi_1.ABI_Type.enum.function);
            return events.map((event) => abi_1.ABI_FunctionZ.parse(event));
        });
    }
    addOrUpdateManyDecodedTx(decodedTxArr) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            try {
                // only way to do bulk upsert
                yield decodedTx_1.DecodedTxModel.bulkWrite(decodedTxArr.map((decodedTx) => ({
                    updateOne: {
                        filter: { txHash: decodedTx.txHash },
                        update: decodedTx,
                        upsert: true,
                    },
                })));
            }
            catch (e) {
                if (!((_a = e === null || e === void 0 ? void 0 : e.message) === null || _a === void 0 ? void 0 : _a.includes('user is not allowed to do action [update]'))) {
                    console.log('decodedTx mongoose error');
                    console.log(e);
                }
            }
        });
    }
    deleteManyDecodedTxs(txHashes) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { acknowledged, deletedCount } = yield decodedTx_1.DecodedTxModel.deleteMany({ txHash: { $in: txHashes } });
                return acknowledged ? deletedCount : 0;
            }
            catch (e) {
                if (!((_a = e === null || e === void 0 ? void 0 : e.message) === null || _a === void 0 ? void 0 : _a.includes('user is not allowed to do action [delete]'))) {
                    console.log('decodedTx mongoose error');
                    console.log(e);
                }
                return 0;
            }
        });
    }
    getManyDecodedTxMap(txHashes) {
        return __awaiter(this, void 0, void 0, function* () {
            const decodedTxMap = {};
            for (let i = 0; i < txHashes.length; i++) {
                decodedTxMap[txHashes[i]] = null;
            }
            // hack for $in being n * log(m) where n = chunk.length and m = db size
            // to actually fix this we'd have to add an 'indexedAddress' column to the DecodedTxModel
            // and we'd probably just have multiple of the same decodedTx in the db in the case that multiple people were part of a tx
            const chunks = (0, collect_js_1.default)(txHashes)
                .chunk(512)
                .all()
                .map((chunk) => chunk.all());
            const promises = chunks.map((chunk) => {
                return decodedTx_1.DecodedTxModel.find({ txHash: { $in: chunk } });
            });
            try {
                const dataChunked = yield Promise.all(promises);
                const modelData = dataChunked.reduce((acc, chunk) => acc.concat(chunk), []);
                // const modelData = await DecodedTxModel.find({ txHash: { $in: txHashes } })
                const data = modelData.map((model) => model.toObject());
                for (let i = 0; i < txHashes.length; i++) {
                    const txHash = txHashes[i];
                    const decodedTx = data.find((tx) => tx.txHash === txHash);
                    decodedTxMap[txHash] = decodedTx || null;
                }
            }
            catch (e) {
                console.log('get decodedTxs mongoose error');
                console.log(e);
                // return null
            }
            // return here instead of in the try, so that it still works if the db is down
            return decodedTxMap;
        });
    }
    getContractsBatch(lastId, batchSize) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const _id = new mongoose_1.Types.ObjectId(lastId);
                const modelData = yield contract_1.ContractModel.find({ _id: { $gt: _id } }).limit(batchSize);
                return modelData;
            }
            catch (e) {
                console.log('get contracts mongoose error');
                console.log(e);
                throw e;
            }
        });
    }
    closeConnection() {
        return __awaiter(this, void 0, void 0, function* () {
            mongoose_1.connection.close();
        });
    }
    getManyNameDataMap(addresses) {
        return __awaiter(this, void 0, void 0, function* () {
            const nameMap = {};
            for (let i = 0; i < addresses.length; i++) {
                nameMap[addresses[i]] = null;
            }
            try {
                const modelData = yield addressName_1.AddressNameModel.find({ address: { $in: addresses } });
                const data = modelData.map((model) => model.toObject());
                for (let i = 0; i < addresses.length; i++) {
                    const address = addresses[i];
                    const addressNameData = data.find((nameData) => nameData.address === address);
                    nameMap[address] = addressNameData || null;
                }
            }
            catch (e) {
                console.log('get nameMap mongoose error');
                console.log(e);
                // return null
            }
            // return here instead of in the try, so that it still works if the db is down
            return nameMap;
        });
    }
    getManyEntityMap(addresses) {
        return __awaiter(this, void 0, void 0, function* () {
            const nameDataMap = yield this.getManyNameDataMap(addresses);
            const entityTuples = (0, utils_1.getEntries)(nameDataMap).map(([address, nameData]) => [address, (nameData === null || nameData === void 0 ? void 0 : nameData.entity) || null]);
            return Object.fromEntries(entityTuples);
        });
    }
    getEntityByAddress(address) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const modelData = yield addressName_1.AddressNameModel.findOne({ address });
                return modelData ? modelData.toObject().entity : null;
            }
            catch (e) {
                console.log('get nameByAddress mongoose error');
                console.log(e);
                throw e;
            }
        });
    }
}
exports.MongooseDatabaseInterface = MongooseDatabaseInterface;
//# sourceMappingURL=index.js.map